# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


class DowntimeRecurrence(ModelNormal):
    validations = {
        "period": {
            "inclusive_maximum": 2147483647,
        },
        "until_occurrences": {
            "inclusive_maximum": 2147483647,
        },
    }
    _nullable = True

    @cached_property
    def openapi_types(_):
        return {
            "period": (int,),
            "rrule": (str,),
            "type": (str,),
            "until_date": (int, none_type),
            "until_occurrences": (int, none_type),
            "week_days": ([str], none_type),
        }

    attribute_map = {
        "period": "period",
        "rrule": "rrule",
        "type": "type",
        "until_date": "until_date",
        "until_occurrences": "until_occurrences",
        "week_days": "week_days",
    }

    def __init__(
        self_,
        period: Union[int, UnsetType] = unset,
        rrule: Union[str, UnsetType] = unset,
        type: Union[str, UnsetType] = unset,
        until_date: Union[int, none_type, UnsetType] = unset,
        until_occurrences: Union[int, none_type, UnsetType] = unset,
        week_days: Union[List[str], none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        An object defining the recurrence of the downtime.

        :param period: How often to repeat as an integer.
            For example, to repeat every 3 days, select a type of ``days`` and a period of ``3``.
        :type period: int, optional

        :param rrule: The ``RRULE`` standard for defining recurring events ( **requires to set "type" to rrule** )
            For example, to have a recurring event on the first day of each month, set the type to ``rrule`` and set the ``FREQ`` to ``MONTHLY`` and ``BYMONTHDAY`` to ``1``.
            Most common ``rrule`` options from the `iCalendar Spec <https://tools.ietf.org/html/rfc5545>`_ are supported.

            **Note** : Attributes specifying the duration in ``RRULE`` are not supported (for example, ``DTSTART`` , ``DTEND`` , ``DURATION`` ).
            More examples available in this `downtime guide <https://docs.datadoghq.com/monitors/guide/suppress-alert-with-downtimes/?tab=api>`_
        :type rrule: str, optional

        :param type: The type of recurrence. Choose from ``days`` , ``weeks`` , ``months`` , ``years`` , ``rrule``.
        :type type: str, optional

        :param until_date: The date at which the recurrence should end as a POSIX timestamp.
            ``until_occurences`` and ``until_date`` are mutually exclusive.
        :type until_date: int, none_type, optional

        :param until_occurrences: How many times the downtime is rescheduled.
            ``until_occurences`` and ``until_date`` are mutually exclusive.
        :type until_occurrences: int, none_type, optional

        :param week_days: A list of week days to repeat on. Choose from ``Mon`` , ``Tue`` , ``Wed`` , ``Thu`` , ``Fri`` , ``Sat`` or ``Sun``.
            Only applicable when type is weeks. First letter must be capitalized.
        :type week_days: [str], none_type, optional
        """
        if period is not unset:
            kwargs["period"] = period
        if rrule is not unset:
            kwargs["rrule"] = rrule
        if type is not unset:
            kwargs["type"] = type
        if until_date is not unset:
            kwargs["until_date"] = until_date
        if until_occurrences is not unset:
            kwargs["until_occurrences"] = until_occurrences
        if week_days is not unset:
            kwargs["week_days"] = week_days
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class RUMAggregationFunction(ModelSimple):
    """
    An aggregation function.

    :param value: Must be one of ["count", "cardinality", "pc75", "pc90", "pc95", "pc98", "pc99", "sum", "min", "max", "avg", "median"].
    :type value: str
    """

    allowed_values = {
        "count",
        "cardinality",
        "pc75",
        "pc90",
        "pc95",
        "pc98",
        "pc99",
        "sum",
        "min",
        "max",
        "avg",
        "median",
    }
    COUNT: ClassVar["RUMAggregationFunction"]
    CARDINALITY: ClassVar["RUMAggregationFunction"]
    PERCENTILE_75: ClassVar["RUMAggregationFunction"]
    PERCENTILE_90: ClassVar["RUMAggregationFunction"]
    PERCENTILE_95: ClassVar["RUMAggregationFunction"]
    PERCENTILE_98: ClassVar["RUMAggregationFunction"]
    PERCENTILE_99: ClassVar["RUMAggregationFunction"]
    SUM: ClassVar["RUMAggregationFunction"]
    MIN: ClassVar["RUMAggregationFunction"]
    MAX: ClassVar["RUMAggregationFunction"]
    AVG: ClassVar["RUMAggregationFunction"]
    MEDIAN: ClassVar["RUMAggregationFunction"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


RUMAggregationFunction.COUNT = RUMAggregationFunction("count")
RUMAggregationFunction.CARDINALITY = RUMAggregationFunction("cardinality")
RUMAggregationFunction.PERCENTILE_75 = RUMAggregationFunction("pc75")
RUMAggregationFunction.PERCENTILE_90 = RUMAggregationFunction("pc90")
RUMAggregationFunction.PERCENTILE_95 = RUMAggregationFunction("pc95")
RUMAggregationFunction.PERCENTILE_98 = RUMAggregationFunction("pc98")
RUMAggregationFunction.PERCENTILE_99 = RUMAggregationFunction("pc99")
RUMAggregationFunction.SUM = RUMAggregationFunction("sum")
RUMAggregationFunction.MIN = RUMAggregationFunction("min")
RUMAggregationFunction.MAX = RUMAggregationFunction("max")
RUMAggregationFunction.AVG = RUMAggregationFunction("avg")
RUMAggregationFunction.MEDIAN = RUMAggregationFunction("median")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.service_definition_meta import ServiceDefinitionMeta
    from datadog_api_client.v2.model.service_definition_schema import ServiceDefinitionSchema
    from datadog_api_client.v2.model.service_definition_v1 import ServiceDefinitionV1
    from datadog_api_client.v2.model.service_definition_v2 import ServiceDefinitionV2


class ServiceDefinitionDataAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.service_definition_meta import ServiceDefinitionMeta
        from datadog_api_client.v2.model.service_definition_schema import ServiceDefinitionSchema

        return {
            "meta": (ServiceDefinitionMeta,),
            "schema": (ServiceDefinitionSchema,),
        }

    attribute_map = {
        "meta": "meta",
        "schema": "schema",
    }

    def __init__(
        self_,
        meta: Union[ServiceDefinitionMeta, UnsetType] = unset,
        schema: Union[ServiceDefinitionSchema, ServiceDefinitionV1, ServiceDefinitionV2, UnsetType] = unset,
        **kwargs,
    ):
        """
        Service definition attributes.

        :param meta: Metadata about a service definition.
        :type meta: ServiceDefinitionMeta, optional

        :param schema: Service definition schema.
        :type schema: ServiceDefinitionSchema, optional
        """
        if meta is not unset:
            kwargs["meta"] = meta
        if schema is not unset:
            kwargs["schema"] = schema
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.logs_metric_create_attributes import LogsMetricCreateAttributes
    from datadog_api_client.v2.model.logs_metric_type import LogsMetricType


class LogsMetricCreateData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.logs_metric_create_attributes import LogsMetricCreateAttributes
        from datadog_api_client.v2.model.logs_metric_type import LogsMetricType

        return {
            "attributes": (LogsMetricCreateAttributes,),
            "id": (str,),
            "type": (LogsMetricType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "id": "id",
        "type": "type",
    }

    def __init__(self_, attributes: LogsMetricCreateAttributes, id: str, type: LogsMetricType, **kwargs):
        """
        The new log-based metric properties.

        :param attributes: The object describing the Datadog log-based metric to create.
        :type attributes: LogsMetricCreateAttributes

        :param id: The name of the log-based metric.
        :type id: str

        :param type: The type of the resource. The value should always be logs_metrics.
        :type type: LogsMetricType
        """
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.id = id
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.hourly_usage_measurement import HourlyUsageMeasurement


class HourlyUsageAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.hourly_usage_measurement import HourlyUsageMeasurement

        return {
            "measurements": ([HourlyUsageMeasurement],),
            "org_name": (str,),
            "product_family": (str,),
            "public_id": (str,),
            "region": (str,),
            "timestamp": (datetime,),
        }

    attribute_map = {
        "measurements": "measurements",
        "org_name": "org_name",
        "product_family": "product_family",
        "public_id": "public_id",
        "region": "region",
        "timestamp": "timestamp",
    }

    def __init__(
        self_,
        measurements: Union[List[HourlyUsageMeasurement], UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        product_family: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        region: Union[str, UnsetType] = unset,
        timestamp: Union[datetime, UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes of hourly usage for a product family for an org for a time period.

        :param measurements: List of the measured usage values for the product family for the org for the time period.
        :type measurements: [HourlyUsageMeasurement], optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param product_family: The product for which usage is being reported.
        :type product_family: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param region: The region of the Datadog instance that the organization belongs to.
        :type region: str, optional

        :param timestamp: Datetime in ISO-8601 format, UTC. The hour for the usage.
        :type timestamp: datetime, optional
        """
        if measurements is not unset:
            kwargs["measurements"] = measurements
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if product_family is not unset:
            kwargs["product_family"] = product_family
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if region is not unset:
            kwargs["region"] = region
        if timestamp is not unset:
            kwargs["timestamp"] = timestamp
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SensitiveDataScannerMeta(ModelNormal):
    validations = {
        "version": {
            "inclusive_minimum": 0,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "count_limit": (int,),
            "group_count_limit": (int,),
            "has_highlight_enabled": (bool,),
            "is_pci_compliant": (bool,),
            "version": (int,),
        }

    attribute_map = {
        "count_limit": "count_limit",
        "group_count_limit": "group_count_limit",
        "has_highlight_enabled": "has_highlight_enabled",
        "is_pci_compliant": "is_pci_compliant",
        "version": "version",
    }

    def __init__(
        self_,
        count_limit: Union[int, UnsetType] = unset,
        group_count_limit: Union[int, UnsetType] = unset,
        has_highlight_enabled: Union[bool, UnsetType] = unset,
        is_pci_compliant: Union[bool, UnsetType] = unset,
        version: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Meta response containing information about the API.

        :param count_limit: Maximum number of scanning rules allowed for the org.
        :type count_limit: int, optional

        :param group_count_limit: Maximum number of scanning groups allowed for the org.
        :type group_count_limit: int, optional

        :param has_highlight_enabled: Whether or not scanned events are highlighted in Logs or RUM for the org.
        :type has_highlight_enabled: bool, optional

        :param is_pci_compliant: Whether or not the org is compliant to the payment card industry standard.
        :type is_pci_compliant: bool, optional

        :param version: Version of the API.
        :type version: int, optional
        """
        if count_limit is not unset:
            kwargs["count_limit"] = count_limit
        if group_count_limit is not unset:
            kwargs["group_count_limit"] = group_count_limit
        if has_highlight_enabled is not unset:
            kwargs["has_highlight_enabled"] = has_highlight_enabled
        if is_pci_compliant is not unset:
            kwargs["is_pci_compliant"] = is_pci_compliant
        if version is not unset:
            kwargs["version"] = version
        super().__init__(kwargs)



from datadog_api_client.v2.api.audit_api import AuditApi
from datadog_api_client.v2.api.authn_mappings_api import AuthNMappingsApi
from datadog_api_client.v2.api.ci_visibility_pipelines_api import CIVisibilityPipelinesApi
from datadog_api_client.v2.api.ci_visibility_tests_api import CIVisibilityTestsApi
from datadog_api_client.v2.api.cloud_workload_security_api import CloudWorkloadSecurityApi
from datadog_api_client.v2.api.confluent_cloud_api import ConfluentCloudApi
from datadog_api_client.v2.api.dashboard_lists_api import DashboardListsApi
from datadog_api_client.v2.api.events_api import EventsApi
from datadog_api_client.v2.api.incident_services_api import IncidentServicesApi
from datadog_api_client.v2.api.incident_teams_api import IncidentTeamsApi
from datadog_api_client.v2.api.incidents_api import IncidentsApi
from datadog_api_client.v2.api.key_management_api import KeyManagementApi
from datadog_api_client.v2.api.logs_api import LogsApi
from datadog_api_client.v2.api.logs_archives_api import LogsArchivesApi
from datadog_api_client.v2.api.logs_metrics_api import LogsMetricsApi
from datadog_api_client.v2.api.metrics_api import MetricsApi
from datadog_api_client.v2.api.opsgenie_integration_api import OpsgenieIntegrationApi
from datadog_api_client.v2.api.organizations_api import OrganizationsApi
from datadog_api_client.v2.api.processes_api import ProcessesApi
from datadog_api_client.v2.api.rum_api import RUMApi
from datadog_api_client.v2.api.roles_api import RolesApi
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
from datadog_api_client.v2.api.sensitive_data_scanner_api import SensitiveDataScannerApi
from datadog_api_client.v2.api.service_accounts_api import ServiceAccountsApi
from datadog_api_client.v2.api.service_definition_api import ServiceDefinitionApi
from datadog_api_client.v2.api.usage_metering_api import UsageMeteringApi
from datadog_api_client.v2.api.users_api import UsersApi



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    file_type,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rules_list_response import (
    CloudWorkloadSecurityAgentRulesListResponse,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_response import (
    CloudWorkloadSecurityAgentRuleResponse,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_request import (
    CloudWorkloadSecurityAgentRuleCreateRequest,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_request import (
    CloudWorkloadSecurityAgentRuleUpdateRequest,
)


class CloudWorkloadSecurityApi:
    """
    Workload activity security rules for generating events using the Datadog security Agent.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_cloud_workload_security_agent_rule_endpoint = _Endpoint(
            settings={
                "response_type": (CloudWorkloadSecurityAgentRuleResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/security_monitoring/cloud_workload_security/agent_rules",
                "operation_id": "create_cloud_workload_security_agent_rule",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (CloudWorkloadSecurityAgentRuleCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_cloud_workload_security_agent_rule_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/security_monitoring/cloud_workload_security/agent_rules/{agent_rule_id}",
                "operation_id": "delete_cloud_workload_security_agent_rule",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "agent_rule_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "agent_rule_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._download_cloud_workload_policy_file_endpoint = _Endpoint(
            settings={
                "response_type": (file_type,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/security/cloud_workload/policy/download",
                "operation_id": "download_cloud_workload_policy_file",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/yaml", "application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_cloud_workload_security_agent_rule_endpoint = _Endpoint(
            settings={
                "response_type": (CloudWorkloadSecurityAgentRuleResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/security_monitoring/cloud_workload_security/agent_rules/{agent_rule_id}",
                "operation_id": "get_cloud_workload_security_agent_rule",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "agent_rule_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "agent_rule_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_cloud_workload_security_agent_rules_endpoint = _Endpoint(
            settings={
                "response_type": (CloudWorkloadSecurityAgentRulesListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/security_monitoring/cloud_workload_security/agent_rules",
                "operation_id": "list_cloud_workload_security_agent_rules",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_cloud_workload_security_agent_rule_endpoint = _Endpoint(
            settings={
                "response_type": (CloudWorkloadSecurityAgentRuleResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/security_monitoring/cloud_workload_security/agent_rules/{agent_rule_id}",
                "operation_id": "update_cloud_workload_security_agent_rule",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "agent_rule_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "agent_rule_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (CloudWorkloadSecurityAgentRuleUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_cloud_workload_security_agent_rule(
        self,
        body: CloudWorkloadSecurityAgentRuleCreateRequest,
    ) -> CloudWorkloadSecurityAgentRuleResponse:
        """Create a Cloud Workload Security Agent rule.

        Create a new Agent rule with the given parameters.

        :param body: The definition of the new Agent rule.
        :type body: CloudWorkloadSecurityAgentRuleCreateRequest
        :rtype: CloudWorkloadSecurityAgentRuleResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_cloud_workload_security_agent_rule_endpoint.call_with_http_info(**kwargs)

    def delete_cloud_workload_security_agent_rule(
        self,
        agent_rule_id: str,
    ) -> None:
        """Delete a Cloud Workload Security Agent rule.

        Delete a specific Agent rule.

        :param agent_rule_id: The ID of the Agent rule.
        :type agent_rule_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["agent_rule_id"] = agent_rule_id

        return self._delete_cloud_workload_security_agent_rule_endpoint.call_with_http_info(**kwargs)

    def download_cloud_workload_policy_file(
        self,
    ) -> file_type:
        """Get the latest Cloud Workload Security policy.

        The download endpoint generates a Cloud Workload Security policy file from your currently active
        Cloud Workload Security rules, and downloads them as a .policy file. This file can then be deployed to
        your Agents to update the policy running in your environment.

        :rtype: file_type
        """
        kwargs: Dict[str, Any] = {}
        return self._download_cloud_workload_policy_file_endpoint.call_with_http_info(**kwargs)

    def get_cloud_workload_security_agent_rule(
        self,
        agent_rule_id: str,
    ) -> CloudWorkloadSecurityAgentRuleResponse:
        """Get a Cloud Workload Security Agent rule.

        Get the details of a specific Agent rule.

        :param agent_rule_id: The ID of the Agent rule.
        :type agent_rule_id: str
        :rtype: CloudWorkloadSecurityAgentRuleResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["agent_rule_id"] = agent_rule_id

        return self._get_cloud_workload_security_agent_rule_endpoint.call_with_http_info(**kwargs)

    def list_cloud_workload_security_agent_rules(
        self,
    ) -> CloudWorkloadSecurityAgentRulesListResponse:
        """Get all Cloud Workload Security Agent rules.

        Get the list of Agent rules.

        :rtype: CloudWorkloadSecurityAgentRulesListResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_cloud_workload_security_agent_rules_endpoint.call_with_http_info(**kwargs)

    def update_cloud_workload_security_agent_rule(
        self,
        agent_rule_id: str,
        body: CloudWorkloadSecurityAgentRuleUpdateRequest,
    ) -> CloudWorkloadSecurityAgentRuleResponse:
        """Update a Cloud Workload Security Agent rule.

        Update a specific Agent rule.
        Returns the Agent rule object when the request is successful.

        :param agent_rule_id: The ID of the Agent rule.
        :type agent_rule_id: str
        :param body: New definition of the Agent rule.
        :type body: CloudWorkloadSecurityAgentRuleUpdateRequest
        :rtype: CloudWorkloadSecurityAgentRuleResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["agent_rule_id"] = agent_rule_id

        kwargs["body"] = body

        return self._update_cloud_workload_security_agent_rule_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
    from datadog_api_client.v1.model.apm_stats_query_definition import ApmStatsQueryDefinition
    from datadog_api_client.v1.model.process_query_definition import ProcessQueryDefinition
    from datadog_api_client.v1.model.distribution_widget_histogram_request_query import (
        DistributionWidgetHistogramRequestQuery,
    )
    from datadog_api_client.v1.model.distribution_widget_histogram_request_type import (
        DistributionWidgetHistogramRequestType,
    )
    from datadog_api_client.v1.model.widget_style import WidgetStyle
    from datadog_api_client.v1.model.formula_and_function_metric_query_definition import (
        FormulaAndFunctionMetricQueryDefinition,
    )
    from datadog_api_client.v1.model.formula_and_function_event_query_definition import (
        FormulaAndFunctionEventQueryDefinition,
    )
    from datadog_api_client.v1.model.formula_and_function_apm_resource_stats_query_definition import (
        FormulaAndFunctionApmResourceStatsQueryDefinition,
    )


class DistributionWidgetRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
        from datadog_api_client.v1.model.apm_stats_query_definition import ApmStatsQueryDefinition
        from datadog_api_client.v1.model.process_query_definition import ProcessQueryDefinition
        from datadog_api_client.v1.model.distribution_widget_histogram_request_query import (
            DistributionWidgetHistogramRequestQuery,
        )
        from datadog_api_client.v1.model.distribution_widget_histogram_request_type import (
            DistributionWidgetHistogramRequestType,
        )
        from datadog_api_client.v1.model.widget_style import WidgetStyle

        return {
            "apm_query": (LogQueryDefinition,),
            "apm_stats_query": (ApmStatsQueryDefinition,),
            "event_query": (LogQueryDefinition,),
            "log_query": (LogQueryDefinition,),
            "network_query": (LogQueryDefinition,),
            "process_query": (ProcessQueryDefinition,),
            "profile_metrics_query": (LogQueryDefinition,),
            "q": (str,),
            "query": (DistributionWidgetHistogramRequestQuery,),
            "request_type": (DistributionWidgetHistogramRequestType,),
            "rum_query": (LogQueryDefinition,),
            "security_query": (LogQueryDefinition,),
            "style": (WidgetStyle,),
        }

    attribute_map = {
        "apm_query": "apm_query",
        "apm_stats_query": "apm_stats_query",
        "event_query": "event_query",
        "log_query": "log_query",
        "network_query": "network_query",
        "process_query": "process_query",
        "profile_metrics_query": "profile_metrics_query",
        "q": "q",
        "query": "query",
        "request_type": "request_type",
        "rum_query": "rum_query",
        "security_query": "security_query",
        "style": "style",
    }

    def __init__(
        self_,
        apm_query: Union[LogQueryDefinition, UnsetType] = unset,
        apm_stats_query: Union[ApmStatsQueryDefinition, UnsetType] = unset,
        event_query: Union[LogQueryDefinition, UnsetType] = unset,
        log_query: Union[LogQueryDefinition, UnsetType] = unset,
        network_query: Union[LogQueryDefinition, UnsetType] = unset,
        process_query: Union[ProcessQueryDefinition, UnsetType] = unset,
        profile_metrics_query: Union[LogQueryDefinition, UnsetType] = unset,
        q: Union[str, UnsetType] = unset,
        query: Union[
            DistributionWidgetHistogramRequestQuery,
            FormulaAndFunctionMetricQueryDefinition,
            FormulaAndFunctionEventQueryDefinition,
            FormulaAndFunctionApmResourceStatsQueryDefinition,
            UnsetType,
        ] = unset,
        request_type: Union[DistributionWidgetHistogramRequestType, UnsetType] = unset,
        rum_query: Union[LogQueryDefinition, UnsetType] = unset,
        security_query: Union[LogQueryDefinition, UnsetType] = unset,
        style: Union[WidgetStyle, UnsetType] = unset,
        **kwargs,
    ):
        """
        Updated distribution widget.

        :param apm_query: The log query.
        :type apm_query: LogQueryDefinition, optional

        :param apm_stats_query: The APM stats query for table and distributions widgets.
        :type apm_stats_query: ApmStatsQueryDefinition, optional

        :param event_query: The log query.
        :type event_query: LogQueryDefinition, optional

        :param log_query: The log query.
        :type log_query: LogQueryDefinition, optional

        :param network_query: The log query.
        :type network_query: LogQueryDefinition, optional

        :param process_query: The process query to use in the widget.
        :type process_query: ProcessQueryDefinition, optional

        :param profile_metrics_query: The log query.
        :type profile_metrics_query: LogQueryDefinition, optional

        :param q: Widget query.
        :type q: str, optional

        :param query: Query definition for Distribution Widget Histogram Request
        :type query: DistributionWidgetHistogramRequestQuery, optional

        :param request_type: Request type for the histogram request.
        :type request_type: DistributionWidgetHistogramRequestType, optional

        :param rum_query: The log query.
        :type rum_query: LogQueryDefinition, optional

        :param security_query: The log query.
        :type security_query: LogQueryDefinition, optional

        :param style: Widget style definition.
        :type style: WidgetStyle, optional
        """
        if apm_query is not unset:
            kwargs["apm_query"] = apm_query
        if apm_stats_query is not unset:
            kwargs["apm_stats_query"] = apm_stats_query
        if event_query is not unset:
            kwargs["event_query"] = event_query
        if log_query is not unset:
            kwargs["log_query"] = log_query
        if network_query is not unset:
            kwargs["network_query"] = network_query
        if process_query is not unset:
            kwargs["process_query"] = process_query
        if profile_metrics_query is not unset:
            kwargs["profile_metrics_query"] = profile_metrics_query
        if q is not unset:
            kwargs["q"] = q
        if query is not unset:
            kwargs["query"] = query
        if request_type is not unset:
            kwargs["request_type"] = request_type
        if rum_query is not unset:
            kwargs["rum_query"] = rum_query
        if security_query is not unset:
            kwargs["security_query"] = security_query
        if style is not unset:
            kwargs["style"] = style
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_test_ci_options import SyntheticsTestCiOptions
    from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
    from datadog_api_client.v1.model.synthetics_test_options_monitor_options import SyntheticsTestOptionsMonitorOptions
    from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles
    from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
    from datadog_api_client.v1.model.synthetics_browser_test_rum_settings import SyntheticsBrowserTestRumSettings


class SyntheticsTestOptions(ModelNormal):
    validations = {
        "monitor_priority": {
            "inclusive_maximum": 5,
            "inclusive_minimum": 1,
        },
        "tick_every": {
            "inclusive_maximum": 604800,
            "inclusive_minimum": 30,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_test_ci_options import SyntheticsTestCiOptions
        from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
        from datadog_api_client.v1.model.synthetics_test_options_monitor_options import (
            SyntheticsTestOptionsMonitorOptions,
        )
        from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles
        from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
        from datadog_api_client.v1.model.synthetics_browser_test_rum_settings import SyntheticsBrowserTestRumSettings

        return {
            "accept_self_signed": (bool,),
            "allow_insecure": (bool,),
            "check_certificate_revocation": (bool,),
            "ci": (SyntheticsTestCiOptions,),
            "device_ids": ([SyntheticsDeviceID],),
            "disable_cors": (bool,),
            "disable_csp": (bool,),
            "follow_redirects": (bool,),
            "ignore_server_certificate_error": (bool,),
            "initial_navigation_timeout": (int,),
            "min_failure_duration": (int,),
            "min_location_failed": (int,),
            "monitor_name": (str,),
            "monitor_options": (SyntheticsTestOptionsMonitorOptions,),
            "monitor_priority": (int,),
            "no_screenshot": (bool,),
            "restricted_roles": (SyntheticsRestrictedRoles,),
            "retry": (SyntheticsTestOptionsRetry,),
            "rum_settings": (SyntheticsBrowserTestRumSettings,),
            "tick_every": (int,),
        }

    attribute_map = {
        "accept_self_signed": "accept_self_signed",
        "allow_insecure": "allow_insecure",
        "check_certificate_revocation": "checkCertificateRevocation",
        "ci": "ci",
        "device_ids": "device_ids",
        "disable_cors": "disableCors",
        "disable_csp": "disableCsp",
        "follow_redirects": "follow_redirects",
        "ignore_server_certificate_error": "ignoreServerCertificateError",
        "initial_navigation_timeout": "initialNavigationTimeout",
        "min_failure_duration": "min_failure_duration",
        "min_location_failed": "min_location_failed",
        "monitor_name": "monitor_name",
        "monitor_options": "monitor_options",
        "monitor_priority": "monitor_priority",
        "no_screenshot": "noScreenshot",
        "restricted_roles": "restricted_roles",
        "retry": "retry",
        "rum_settings": "rumSettings",
        "tick_every": "tick_every",
    }

    def __init__(
        self_,
        accept_self_signed: Union[bool, UnsetType] = unset,
        allow_insecure: Union[bool, UnsetType] = unset,
        check_certificate_revocation: Union[bool, UnsetType] = unset,
        ci: Union[SyntheticsTestCiOptions, UnsetType] = unset,
        device_ids: Union[List[SyntheticsDeviceID], UnsetType] = unset,
        disable_cors: Union[bool, UnsetType] = unset,
        disable_csp: Union[bool, UnsetType] = unset,
        follow_redirects: Union[bool, UnsetType] = unset,
        ignore_server_certificate_error: Union[bool, UnsetType] = unset,
        initial_navigation_timeout: Union[int, UnsetType] = unset,
        min_failure_duration: Union[int, UnsetType] = unset,
        min_location_failed: Union[int, UnsetType] = unset,
        monitor_name: Union[str, UnsetType] = unset,
        monitor_options: Union[SyntheticsTestOptionsMonitorOptions, UnsetType] = unset,
        monitor_priority: Union[int, UnsetType] = unset,
        no_screenshot: Union[bool, UnsetType] = unset,
        restricted_roles: Union[SyntheticsRestrictedRoles, UnsetType] = unset,
        retry: Union[SyntheticsTestOptionsRetry, UnsetType] = unset,
        rum_settings: Union[SyntheticsBrowserTestRumSettings, UnsetType] = unset,
        tick_every: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object describing the extra options for a Synthetic test.

        :param accept_self_signed: For SSL test, whether or not the test should allow self signed
            certificates.
        :type accept_self_signed: bool, optional

        :param allow_insecure: Allows loading insecure content for an HTTP request in an API test.
        :type allow_insecure: bool, optional

        :param check_certificate_revocation: For SSL test, whether or not the test should fail on revoked certificate in stapled OCSP.
        :type check_certificate_revocation: bool, optional

        :param ci: CI/CD options for a Synthetic test.
        :type ci: SyntheticsTestCiOptions, optional

        :param device_ids: For browser test, array with the different device IDs used to run the test.
        :type device_ids: [SyntheticsDeviceID], optional

        :param disable_cors: Whether or not to disable CORS mechanism.
        :type disable_cors: bool, optional

        :param disable_csp: Disable Content Security Policy for browser tests.
        :type disable_csp: bool, optional

        :param follow_redirects: For API HTTP test, whether or not the test should follow redirects.
        :type follow_redirects: bool, optional

        :param ignore_server_certificate_error: Ignore server certificate error for browser tests.
        :type ignore_server_certificate_error: bool, optional

        :param initial_navigation_timeout: Timeout before declaring the initial step as failed (in seconds) for browser tests.
        :type initial_navigation_timeout: int, optional

        :param min_failure_duration: Minimum amount of time in failure required to trigger an alert.
        :type min_failure_duration: int, optional

        :param min_location_failed: Minimum number of locations in failure required to trigger
            an alert.
        :type min_location_failed: int, optional

        :param monitor_name: The monitor name is used for the alert title as well as for all monitor dashboard widgets and SLOs.
        :type monitor_name: str, optional

        :param monitor_options: Object containing the options for a Synthetic test as a monitor
            (for example, renotification).
        :type monitor_options: SyntheticsTestOptionsMonitorOptions, optional

        :param monitor_priority: Integer from 1 (high) to 5 (low) indicating alert severity.
        :type monitor_priority: int, optional

        :param no_screenshot: Prevents saving screenshots of the steps.
        :type no_screenshot: bool, optional

        :param restricted_roles: A list of role identifiers that can be pulled from the Roles API, for restricting read and write access.
        :type restricted_roles: SyntheticsRestrictedRoles, optional

        :param retry: Object describing the retry strategy to apply to a Synthetic test.
        :type retry: SyntheticsTestOptionsRetry, optional

        :param rum_settings: The RUM data collection settings for the Synthetic browser test.
            **Note:** There are 3 ways to format RUM settings:

            ``{ isEnabled: false }``
            RUM data is not collected.

            ``{ isEnabled: true }``
            RUM data is collected from the Synthetic test's default application.

            ``{ isEnabled: true, applicationId: "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx", clientTokenId: 12345 }``
            RUM data is collected using the specified application.
        :type rum_settings: SyntheticsBrowserTestRumSettings, optional

        :param tick_every: The frequency at which to run the Synthetic test (in seconds).
        :type tick_every: int, optional
        """
        if accept_self_signed is not unset:
            kwargs["accept_self_signed"] = accept_self_signed
        if allow_insecure is not unset:
            kwargs["allow_insecure"] = allow_insecure
        if check_certificate_revocation is not unset:
            kwargs["check_certificate_revocation"] = check_certificate_revocation
        if ci is not unset:
            kwargs["ci"] = ci
        if device_ids is not unset:
            kwargs["device_ids"] = device_ids
        if disable_cors is not unset:
            kwargs["disable_cors"] = disable_cors
        if disable_csp is not unset:
            kwargs["disable_csp"] = disable_csp
        if follow_redirects is not unset:
            kwargs["follow_redirects"] = follow_redirects
        if ignore_server_certificate_error is not unset:
            kwargs["ignore_server_certificate_error"] = ignore_server_certificate_error
        if initial_navigation_timeout is not unset:
            kwargs["initial_navigation_timeout"] = initial_navigation_timeout
        if min_failure_duration is not unset:
            kwargs["min_failure_duration"] = min_failure_duration
        if min_location_failed is not unset:
            kwargs["min_location_failed"] = min_location_failed
        if monitor_name is not unset:
            kwargs["monitor_name"] = monitor_name
        if monitor_options is not unset:
            kwargs["monitor_options"] = monitor_options
        if monitor_priority is not unset:
            kwargs["monitor_priority"] = monitor_priority
        if no_screenshot is not unset:
            kwargs["no_screenshot"] = no_screenshot
        if restricted_roles is not unset:
            kwargs["restricted_roles"] = restricted_roles
        if retry is not unset:
            kwargs["retry"] = retry
        if rum_settings is not unset:
            kwargs["rum_settings"] = rum_settings
        if tick_every is not unset:
            kwargs["tick_every"] = tick_every
        super().__init__(kwargs)



"""
Get all service objects returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.opsgenie_integration_api import OpsgenieIntegrationApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = OpsgenieIntegrationApi(api_client)
    response = api_instance.list_opsgenie_services()

    print(response)



from datadog_api_client.v1.model.monitor_thresholds import MonitorThresholds
from datadog_api_client.v2.model.logs_group_by import LogsGroupBy
from datadog_api_client.v2.model.logs_group_by_missing import LogsGroupByMissing
from datadog_api_client.v2.model.logs_group_by_total import LogsGroupByTotal
from datadog_api_client.v2.model.logs_aggregate_sort import LogsAggregateSort
from datadog_api_client.v2.model.logs_aggregate_sort_type import LogsAggregateSortType
from datadog_api_client.v2.model.logs_aggregation_function import LogsAggregationFunction
from datadog_api_client.v2.model.logs_sort_order import LogsSortOrder


def test_default_coerce():
    thresholds = MonitorThresholds(critical=5)
    assert thresholds["critical"] == 5.0


def test_primitive_one_of():
    group_by = LogsGroupBy(
        facet="host",
        missing=LogsGroupByMissing("miss"),
        sort=LogsAggregateSort(
            type=LogsAggregateSortType("measure"),
            order=LogsSortOrder("asc"),
            aggregation=LogsAggregationFunction("pc90"),
            metric="@duration",
        ),
        total=LogsGroupByTotal("recall"),
    )

    assert group_by.missing == "miss"



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.user_list_response import UserListResponse
from datadog_api_client.v1.model.user_response import UserResponse
from datadog_api_client.v1.model.user import User
from datadog_api_client.v1.model.user_disable_response import UserDisableResponse


class UsersApi:
    """
    Create, edit, and disable users.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_user_endpoint = _Endpoint(
            settings={
                "response_type": (UserResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/user",
                "operation_id": "create_user",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (User,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._disable_user_endpoint = _Endpoint(
            settings={
                "response_type": (UserDisableResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/user/{user_handle}",
                "operation_id": "disable_user",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "user_handle": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "user_handle",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_user_endpoint = _Endpoint(
            settings={
                "response_type": (UserResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/user/{user_handle}",
                "operation_id": "get_user",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "user_handle": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "user_handle",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_users_endpoint = _Endpoint(
            settings={
                "response_type": (UserListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/user",
                "operation_id": "list_users",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_user_endpoint = _Endpoint(
            settings={
                "response_type": (UserResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/user/{user_handle}",
                "operation_id": "update_user",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "user_handle": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "user_handle",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (User,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_user(
        self,
        body: User,
    ) -> UserResponse:
        """Create a user.

        Create a user for your organization.

        **Note** : Users can only be created with the admin access role
        if application keys belong to administrators.

        :param body: User object that needs to be created.
        :type body: User
        :rtype: UserResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_user_endpoint.call_with_http_info(**kwargs)

    def disable_user(
        self,
        user_handle: str,
    ) -> UserDisableResponse:
        """Disable a user.

        Delete a user from an organization.

        **Note** : This endpoint can only be used with application keys belonging to
        administrators.

        :param user_handle: The handle of the user.
        :type user_handle: str
        :rtype: UserDisableResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["user_handle"] = user_handle

        return self._disable_user_endpoint.call_with_http_info(**kwargs)

    def get_user(
        self,
        user_handle: str,
    ) -> UserResponse:
        """Get user details.

        Get a user's details.

        :param user_handle: The ID of the user.
        :type user_handle: str
        :rtype: UserResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["user_handle"] = user_handle

        return self._get_user_endpoint.call_with_http_info(**kwargs)

    def list_users(
        self,
    ) -> UserListResponse:
        """List all users.

        List all users for your organization.

        :rtype: UserListResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_users_endpoint.call_with_http_info(**kwargs)

    def update_user(
        self,
        user_handle: str,
        body: User,
    ) -> UserResponse:
        """Update a user.

        Update a user information.

        **Note** : It can only be used with application keys belonging to administrators.

        :param user_handle: The ID of the user.
        :type user_handle: str
        :param body: Description of the update.
        :type body: User
        :rtype: UserResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["user_handle"] = user_handle

        kwargs["body"] = body

        return self._update_user_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.cloud_configuration_compliance_rule_options import (
        CloudConfigurationComplianceRuleOptions,
    )
    from datadog_api_client.v2.model.security_monitoring_rule_detection_method import (
        SecurityMonitoringRuleDetectionMethod,
    )
    from datadog_api_client.v2.model.security_monitoring_rule_evaluation_window import (
        SecurityMonitoringRuleEvaluationWindow,
    )
    from datadog_api_client.v2.model.security_monitoring_rule_hardcoded_evaluator_type import (
        SecurityMonitoringRuleHardcodedEvaluatorType,
    )
    from datadog_api_client.v2.model.security_monitoring_rule_impossible_travel_options import (
        SecurityMonitoringRuleImpossibleTravelOptions,
    )
    from datadog_api_client.v2.model.security_monitoring_rule_keep_alive import SecurityMonitoringRuleKeepAlive
    from datadog_api_client.v2.model.security_monitoring_rule_max_signal_duration import (
        SecurityMonitoringRuleMaxSignalDuration,
    )
    from datadog_api_client.v2.model.security_monitoring_rule_new_value_options import (
        SecurityMonitoringRuleNewValueOptions,
    )


class SecurityMonitoringRuleOptions(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.cloud_configuration_compliance_rule_options import (
            CloudConfigurationComplianceRuleOptions,
        )
        from datadog_api_client.v2.model.security_monitoring_rule_detection_method import (
            SecurityMonitoringRuleDetectionMethod,
        )
        from datadog_api_client.v2.model.security_monitoring_rule_evaluation_window import (
            SecurityMonitoringRuleEvaluationWindow,
        )
        from datadog_api_client.v2.model.security_monitoring_rule_hardcoded_evaluator_type import (
            SecurityMonitoringRuleHardcodedEvaluatorType,
        )
        from datadog_api_client.v2.model.security_monitoring_rule_impossible_travel_options import (
            SecurityMonitoringRuleImpossibleTravelOptions,
        )
        from datadog_api_client.v2.model.security_monitoring_rule_keep_alive import SecurityMonitoringRuleKeepAlive
        from datadog_api_client.v2.model.security_monitoring_rule_max_signal_duration import (
            SecurityMonitoringRuleMaxSignalDuration,
        )
        from datadog_api_client.v2.model.security_monitoring_rule_new_value_options import (
            SecurityMonitoringRuleNewValueOptions,
        )

        return {
            "compliance_rule_options": (CloudConfigurationComplianceRuleOptions,),
            "decrease_criticality_based_on_env": (bool,),
            "detection_method": (SecurityMonitoringRuleDetectionMethod,),
            "evaluation_window": (SecurityMonitoringRuleEvaluationWindow,),
            "hardcoded_evaluator_type": (SecurityMonitoringRuleHardcodedEvaluatorType,),
            "impossible_travel_options": (SecurityMonitoringRuleImpossibleTravelOptions,),
            "keep_alive": (SecurityMonitoringRuleKeepAlive,),
            "max_signal_duration": (SecurityMonitoringRuleMaxSignalDuration,),
            "new_value_options": (SecurityMonitoringRuleNewValueOptions,),
        }

    attribute_map = {
        "compliance_rule_options": "complianceRuleOptions",
        "decrease_criticality_based_on_env": "decreaseCriticalityBasedOnEnv",
        "detection_method": "detectionMethod",
        "evaluation_window": "evaluationWindow",
        "hardcoded_evaluator_type": "hardcodedEvaluatorType",
        "impossible_travel_options": "impossibleTravelOptions",
        "keep_alive": "keepAlive",
        "max_signal_duration": "maxSignalDuration",
        "new_value_options": "newValueOptions",
    }

    def __init__(
        self_,
        compliance_rule_options: Union[CloudConfigurationComplianceRuleOptions, UnsetType] = unset,
        decrease_criticality_based_on_env: Union[bool, UnsetType] = unset,
        detection_method: Union[SecurityMonitoringRuleDetectionMethod, UnsetType] = unset,
        evaluation_window: Union[SecurityMonitoringRuleEvaluationWindow, UnsetType] = unset,
        hardcoded_evaluator_type: Union[SecurityMonitoringRuleHardcodedEvaluatorType, UnsetType] = unset,
        impossible_travel_options: Union[SecurityMonitoringRuleImpossibleTravelOptions, UnsetType] = unset,
        keep_alive: Union[SecurityMonitoringRuleKeepAlive, UnsetType] = unset,
        max_signal_duration: Union[SecurityMonitoringRuleMaxSignalDuration, UnsetType] = unset,
        new_value_options: Union[SecurityMonitoringRuleNewValueOptions, UnsetType] = unset,
        **kwargs,
    ):
        """
        Options on rules.

        :param compliance_rule_options: Options for cloud_configuration rules.
            Fields ``resourceType`` and ``regoRule`` are mandatory when managing custom ``cloud_configuration`` rules.
        :type compliance_rule_options: CloudConfigurationComplianceRuleOptions, optional

        :param decrease_criticality_based_on_env: If true, signals in non-production environments have a lower severity than what is defined by the rule case, which can reduce signal noise.
            The severity is decreased by one level: ``CRITICAL`` in production becomes ``HIGH`` in non-production, ``HIGH`` becomes ``MEDIUM`` and so on. ``INFO`` remains ``INFO``.
            The decrement is applied when the environment tag of the signal starts with ``staging`` , ``test`` or ``dev``.
        :type decrease_criticality_based_on_env: bool, optional

        :param detection_method: The detection method.
        :type detection_method: SecurityMonitoringRuleDetectionMethod, optional

        :param evaluation_window: A time window is specified to match when at least one of the cases matches true. This is a sliding window
            and evaluates in real time.
        :type evaluation_window: SecurityMonitoringRuleEvaluationWindow, optional

        :param hardcoded_evaluator_type: Hardcoded evaluator type.
        :type hardcoded_evaluator_type: SecurityMonitoringRuleHardcodedEvaluatorType, optional

        :param impossible_travel_options: Options on impossible travel rules.
        :type impossible_travel_options: SecurityMonitoringRuleImpossibleTravelOptions, optional

        :param keep_alive: Once a signal is generated, the signal will remain “open” if a case is matched at least once within
            this keep alive window.
        :type keep_alive: SecurityMonitoringRuleKeepAlive, optional

        :param max_signal_duration: A signal will “close” regardless of the query being matched once the time exceeds the maximum duration.
            This time is calculated from the first seen timestamp.
        :type max_signal_duration: SecurityMonitoringRuleMaxSignalDuration, optional

        :param new_value_options: Options on new value rules.
        :type new_value_options: SecurityMonitoringRuleNewValueOptions, optional
        """
        if compliance_rule_options is not unset:
            kwargs["compliance_rule_options"] = compliance_rule_options
        if decrease_criticality_based_on_env is not unset:
            kwargs["decrease_criticality_based_on_env"] = decrease_criticality_based_on_env
        if detection_method is not unset:
            kwargs["detection_method"] = detection_method
        if evaluation_window is not unset:
            kwargs["evaluation_window"] = evaluation_window
        if hardcoded_evaluator_type is not unset:
            kwargs["hardcoded_evaluator_type"] = hardcoded_evaluator_type
        if impossible_travel_options is not unset:
            kwargs["impossible_travel_options"] = impossible_travel_options
        if keep_alive is not unset:
            kwargs["keep_alive"] = keep_alive
        if max_signal_duration is not unset:
            kwargs["max_signal_duration"] = max_signal_duration
        if new_value_options is not unset:
            kwargs["new_value_options"] = new_value_options
        super().__init__(kwargs)



"""
Create a new dashboard with check_status widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.check_status_widget_definition import CheckStatusWidgetDefinition
from datadog_api_client.v1.model.check_status_widget_definition_type import CheckStatusWidgetDefinitionType
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_grouping import WidgetGrouping
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_check_status_widget",
    description="",
    widgets=[
        Widget(
            layout=WidgetLayout(
                x=0,
                y=0,
                width=15,
                height=8,
            ),
            definition=CheckStatusWidgetDefinition(
                title_size="16",
                title_align=WidgetTextAlign.LEFT,
                type=CheckStatusWidgetDefinitionType.CHECK_STATUS,
                check="datadog.agent.up",
                grouping=WidgetGrouping.CHECK,
                tags=[
                    "*",
                ],
            ),
        ),
    ],
    template_variables=[],
    layout_type=DashboardLayoutType.FREE,
    is_read_only=False,
    notify_list=[],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

import collections
from typing import Any, Dict, List, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    set_attribute_from_path,
    get_attribute_from_path,
    UnsetType,
    unset,
)
from datadog_api_client.v2.model.incidents_response import IncidentsResponse
from datadog_api_client.v2.model.incident_related_object import IncidentRelatedObject
from datadog_api_client.v2.model.incident_response_data import IncidentResponseData
from datadog_api_client.v2.model.incident_response import IncidentResponse
from datadog_api_client.v2.model.incident_create_request import IncidentCreateRequest
from datadog_api_client.v2.model.incident_update_request import IncidentUpdateRequest
from datadog_api_client.v2.model.incident_attachments_response import IncidentAttachmentsResponse
from datadog_api_client.v2.model.incident_attachment_related_object import IncidentAttachmentRelatedObject
from datadog_api_client.v2.model.incident_attachment_attachment_type import IncidentAttachmentAttachmentType
from datadog_api_client.v2.model.incident_attachment_update_response import IncidentAttachmentUpdateResponse
from datadog_api_client.v2.model.incident_attachment_update_request import IncidentAttachmentUpdateRequest


class IncidentsApi:
    """
    Manage incident response.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_incident_endpoint = _Endpoint(
            settings={
                "response_type": (IncidentResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/incidents",
                "operation_id": "create_incident",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (IncidentCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_incident_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/incidents/{incident_id}",
                "operation_id": "delete_incident",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "incident_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "incident_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_incident_endpoint = _Endpoint(
            settings={
                "response_type": (IncidentResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/incidents/{incident_id}",
                "operation_id": "get_incident",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "incident_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "incident_id",
                    "location": "path",
                },
                "include": {
                    "openapi_types": ([IncidentRelatedObject],),
                    "attribute": "include",
                    "location": "query",
                    "collection_format": "csv",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_incident_attachments_endpoint = _Endpoint(
            settings={
                "response_type": (IncidentAttachmentsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/incidents/{incident_id}/attachments",
                "operation_id": "list_incident_attachments",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "incident_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "incident_id",
                    "location": "path",
                },
                "include": {
                    "openapi_types": ([IncidentAttachmentRelatedObject],),
                    "attribute": "include",
                    "location": "query",
                    "collection_format": "csv",
                },
                "filter_attachment_type": {
                    "openapi_types": ([IncidentAttachmentAttachmentType],),
                    "attribute": "filter[attachment_type]",
                    "location": "query",
                    "collection_format": "csv",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_incidents_endpoint = _Endpoint(
            settings={
                "response_type": (IncidentsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/incidents",
                "operation_id": "list_incidents",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "include": {
                    "openapi_types": ([IncidentRelatedObject],),
                    "attribute": "include",
                    "location": "query",
                    "collection_format": "csv",
                },
                "page_size": {
                    "openapi_types": (int,),
                    "attribute": "page[size]",
                    "location": "query",
                },
                "page_offset": {
                    "openapi_types": (int,),
                    "attribute": "page[offset]",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_incident_endpoint = _Endpoint(
            settings={
                "response_type": (IncidentResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/incidents/{incident_id}",
                "operation_id": "update_incident",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "incident_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "incident_id",
                    "location": "path",
                },
                "include": {
                    "openapi_types": ([IncidentRelatedObject],),
                    "attribute": "include",
                    "location": "query",
                    "collection_format": "csv",
                },
                "body": {
                    "required": True,
                    "openapi_types": (IncidentUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_incident_attachments_endpoint = _Endpoint(
            settings={
                "response_type": (IncidentAttachmentUpdateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/incidents/{incident_id}/attachments",
                "operation_id": "update_incident_attachments",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "incident_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "incident_id",
                    "location": "path",
                },
                "include": {
                    "openapi_types": ([IncidentAttachmentRelatedObject],),
                    "attribute": "include",
                    "location": "query",
                    "collection_format": "csv",
                },
                "body": {
                    "required": True,
                    "openapi_types": (IncidentAttachmentUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_incident(
        self,
        body: IncidentCreateRequest,
    ) -> IncidentResponse:
        """Create an incident.

        Create an incident.

        :param body: Incident payload.
        :type body: IncidentCreateRequest
        :rtype: IncidentResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_incident_endpoint.call_with_http_info(**kwargs)

    def delete_incident(
        self,
        incident_id: str,
    ) -> None:
        """Delete an existing incident.

        Deletes an existing incident from the users organization.

        :param incident_id: The UUID of the incident.
        :type incident_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["incident_id"] = incident_id

        return self._delete_incident_endpoint.call_with_http_info(**kwargs)

    def get_incident(
        self,
        incident_id: str,
        *,
        include: Union[List[IncidentRelatedObject], UnsetType] = unset,
    ) -> IncidentResponse:
        """Get the details of an incident.

        Get the details of an incident by ``incident_id``.

        :param incident_id: The UUID of the incident.
        :type incident_id: str
        :param include: Specifies which types of related objects should be included in the response.
        :type include: [IncidentRelatedObject], optional
        :rtype: IncidentResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["incident_id"] = incident_id

        if include is not unset:
            kwargs["include"] = include

        return self._get_incident_endpoint.call_with_http_info(**kwargs)

    def list_incident_attachments(
        self,
        incident_id: str,
        *,
        include: Union[List[IncidentAttachmentRelatedObject], UnsetType] = unset,
        filter_attachment_type: Union[List[IncidentAttachmentAttachmentType], UnsetType] = unset,
    ) -> IncidentAttachmentsResponse:
        """Get a list of attachments.

        Get all attachments for a given incident.

        :param incident_id: The UUID of the incident.
        :type incident_id: str
        :param include: Specifies which types of related objects are included in the response.
        :type include: [IncidentAttachmentRelatedObject], optional
        :param filter_attachment_type: Specifies which types of attachments are included in the response.
        :type filter_attachment_type: [IncidentAttachmentAttachmentType], optional
        :rtype: IncidentAttachmentsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["incident_id"] = incident_id

        if include is not unset:
            kwargs["include"] = include

        if filter_attachment_type is not unset:
            kwargs["filter_attachment_type"] = filter_attachment_type

        return self._list_incident_attachments_endpoint.call_with_http_info(**kwargs)

    def list_incidents(
        self,
        *,
        include: Union[List[IncidentRelatedObject], UnsetType] = unset,
        page_size: Union[int, UnsetType] = unset,
        page_offset: Union[int, UnsetType] = unset,
    ) -> IncidentsResponse:
        """Get a list of incidents.

        Get all incidents for the user's organization.

        :param include: Specifies which types of related objects should be included in the response.
        :type include: [IncidentRelatedObject], optional
        :param page_size: Size for a given page. The maximum allowed value is 5000.
        :type page_size: int, optional
        :param page_offset: Specific offset to use as the beginning of the returned page.
        :type page_offset: int, optional
        :rtype: IncidentsResponse
        """
        kwargs: Dict[str, Any] = {}
        if include is not unset:
            kwargs["include"] = include

        if page_size is not unset:
            kwargs["page_size"] = page_size

        if page_offset is not unset:
            kwargs["page_offset"] = page_offset

        return self._list_incidents_endpoint.call_with_http_info(**kwargs)

    def list_incidents_with_pagination(
        self,
        *,
        include: Union[List[IncidentRelatedObject], UnsetType] = unset,
        page_size: Union[int, UnsetType] = unset,
        page_offset: Union[int, UnsetType] = unset,
    ) -> collections.abc.Iterable[IncidentResponseData]:
        """Get a list of incidents.

        Provide a paginated version of :meth:`list_incidents`, returning all items.

        :param include: Specifies which types of related objects should be included in the response.
        :type include: [IncidentRelatedObject], optional
        :param page_size: Size for a given page. The maximum allowed value is 5000.
        :type page_size: int, optional
        :param page_offset: Specific offset to use as the beginning of the returned page.
        :type page_offset: int, optional

        :return: A generator of paginated results.
        :rtype: collections.abc.Iterable[IncidentResponseData]
        """
        kwargs: Dict[str, Any] = {}
        if include is not unset:
            kwargs["include"] = include

        if page_size is not unset:
            kwargs["page_size"] = page_size

        if page_offset is not unset:
            kwargs["page_offset"] = page_offset

        local_page_size = get_attribute_from_path(kwargs, "page_size", 10)
        endpoint = self._list_incidents_endpoint
        set_attribute_from_path(kwargs, "page_size", local_page_size, endpoint.params_map)
        while True:
            response = endpoint.call_with_http_info(**kwargs)
            for item in get_attribute_from_path(response, "data"):
                yield item
            if len(get_attribute_from_path(response, "data")) < local_page_size:
                break
            set_attribute_from_path(
                kwargs,
                "page_offset",
                get_attribute_from_path(kwargs, "page_offset", 0) + local_page_size,
                endpoint.params_map,
            )

    def update_incident(
        self,
        incident_id: str,
        body: IncidentUpdateRequest,
        *,
        include: Union[List[IncidentRelatedObject], UnsetType] = unset,
    ) -> IncidentResponse:
        """Update an existing incident.

        Updates an incident. Provide only the attributes that should be updated as this request is a partial update.

        :param incident_id: The UUID of the incident.
        :type incident_id: str
        :param body: Incident Payload.
        :type body: IncidentUpdateRequest
        :param include: Specifies which types of related objects should be included in the response.
        :type include: [IncidentRelatedObject], optional
        :rtype: IncidentResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["incident_id"] = incident_id

        if include is not unset:
            kwargs["include"] = include

        kwargs["body"] = body

        return self._update_incident_endpoint.call_with_http_info(**kwargs)

    def update_incident_attachments(
        self,
        incident_id: str,
        body: IncidentAttachmentUpdateRequest,
        *,
        include: Union[List[IncidentAttachmentRelatedObject], UnsetType] = unset,
    ) -> IncidentAttachmentUpdateResponse:
        """Create, update, and delete incident attachments.

        The bulk update endpoint for creating, updating, and deleting attachments for a given incident.

        :param incident_id: The UUID of the incident.
        :type incident_id: str
        :param body: Incident Attachment Payload.
        :type body: IncidentAttachmentUpdateRequest
        :param include: Specifies which types of related objects are included in the response.
        :type include: [IncidentAttachmentRelatedObject], optional
        :rtype: IncidentAttachmentUpdateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["incident_id"] = incident_id

        if include is not unset:
            kwargs["include"] = include

        kwargs["body"] = body

        return self._update_incident_attachments_endpoint.call_with_http_info(**kwargs)



"""
Aggregate tests events returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.ci_visibility_tests_api import CIVisibilityTestsApi
from datadog_api_client.v2.model.ci_app_aggregate_sort import CIAppAggregateSort
from datadog_api_client.v2.model.ci_app_aggregation_function import CIAppAggregationFunction
from datadog_api_client.v2.model.ci_app_compute import CIAppCompute
from datadog_api_client.v2.model.ci_app_compute_type import CIAppComputeType
from datadog_api_client.v2.model.ci_app_query_options import CIAppQueryOptions
from datadog_api_client.v2.model.ci_app_query_page_options import CIAppQueryPageOptions
from datadog_api_client.v2.model.ci_app_sort_order import CIAppSortOrder
from datadog_api_client.v2.model.ci_app_tests_aggregate_request import CIAppTestsAggregateRequest
from datadog_api_client.v2.model.ci_app_tests_group_by import CIAppTestsGroupBy
from datadog_api_client.v2.model.ci_app_tests_query_filter import CIAppTestsQueryFilter

body = CIAppTestsAggregateRequest(
    compute=[
        CIAppCompute(
            aggregation=CIAppAggregationFunction.COUNT,
            metric="@test.is_flaky",
            type=CIAppComputeType.TOTAL,
        ),
    ],
    filter=CIAppTestsQueryFilter(
        _from="now-15m",
        query="@language:(python OR go)",
        to="now",
    ),
    group_by=[
        CIAppTestsGroupBy(
            facet="@git.branch",
            limit=10,
            sort=CIAppAggregateSort(
                order=CIAppSortOrder.ASCENDING,
            ),
            total=False,
        ),
    ],
    options=CIAppQueryOptions(
        timezone="GMT",
    ),
    page=CIAppQueryPageOptions(
        limit=25,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = CIVisibilityTestsApi(api_client)
    response = api_instance.aggregate_ci_app_test_events(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.dashboard_list_item_request import DashboardListItemRequest


class DashboardListUpdateItemsRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.dashboard_list_item_request import DashboardListItemRequest

        return {
            "dashboards": ([DashboardListItemRequest],),
        }

    attribute_map = {
        "dashboards": "dashboards",
    }

    def __init__(self_, dashboards: Union[List[DashboardListItemRequest], UnsetType] = unset, **kwargs):
        """
        Request containing the list of dashboards to update to.

        :param dashboards: List of dashboards to update the dashboard list to.
        :type dashboards: [DashboardListItemRequest], optional
        """
        if dashboards is not unset:
            kwargs["dashboards"] = dashboards
        super().__init__(kwargs)



"""
List all GCP integrations returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.gcp_integration_api import GCPIntegrationApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = GCPIntegrationApi(api_client)
    response = api_instance.list_gcp_integration()

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.organization import Organization


class OrganizationListResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.organization import Organization

        return {
            "orgs": ([Organization],),
        }

    attribute_map = {
        "orgs": "orgs",
    }

    def __init__(self_, orgs: Union[List[Organization], UnsetType] = unset, **kwargs):
        """
        Response with the list of organizations.

        :param orgs: Array of organization objects.
        :type orgs: [Organization], optional
        """
        if orgs is not unset:
            kwargs["orgs"] = orgs
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.event import Event


class EventCreateResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.event import Event

        return {
            "event": (Event,),
            "status": (str,),
        }

    attribute_map = {
        "event": "event",
        "status": "status",
    }

    def __init__(self_, event: Union[Event, UnsetType] = unset, status: Union[str, UnsetType] = unset, **kwargs):
        """
        Object containing an event response.

        :param event: Object representing an event.
        :type event: Event, optional

        :param status: A status.
        :type status: str, optional
        """
        if event is not unset:
            kwargs["event"] = event
        if status is not unset:
            kwargs["status"] = status
        super().__init__(kwargs)



"""
Send invitation emails returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.users_api import UsersApi
from datadog_api_client.v2.model.relationship_to_user import RelationshipToUser
from datadog_api_client.v2.model.relationship_to_user_data import RelationshipToUserData
from datadog_api_client.v2.model.user_invitation_data import UserInvitationData
from datadog_api_client.v2.model.user_invitation_relationships import UserInvitationRelationships
from datadog_api_client.v2.model.user_invitations_request import UserInvitationsRequest
from datadog_api_client.v2.model.user_invitations_type import UserInvitationsType
from datadog_api_client.v2.model.users_type import UsersType

# there is a valid "user" in the system
USER_DATA_ID = environ["USER_DATA_ID"]

body = UserInvitationsRequest(
    data=[
        UserInvitationData(
            type=UserInvitationsType.USER_INVITATIONS,
            relationships=UserInvitationRelationships(
                user=RelationshipToUser(
                    data=RelationshipToUserData(
                        type=UsersType.USERS,
                        id=USER_DATA_ID,
                    ),
                ),
            ),
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = UsersApi(api_client)
    response = api_instance.send_invitations(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelComposed,
    cached_property,
)


class LogsArchiveDestination(ModelComposed):

    _nullable = True

    def __init__(self, **kwargs):
        """
        An archive's destination.

        :param container: The container where the archive will be stored.
        :type container: str

        :param integration: The Azure archive's integration destination.
        :type integration: LogsArchiveIntegrationAzure

        :param path: The archive path.
        :type path: str, optional

        :param region: The region where the archive will be stored.
        :type region: str, optional

        :param storage_account: The associated storage account.
        :type storage_account: str

        :param type: Type of the Azure archive destination.
        :type type: LogsArchiveDestinationAzureType

        :param bucket: The bucket where the archive will be stored.
        :type bucket: str
        """
        super().__init__(kwargs)

    @cached_property
    def _composed_schemas(_):
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        from datadog_api_client.v2.model.logs_archive_destination_azure import LogsArchiveDestinationAzure
        from datadog_api_client.v2.model.logs_archive_destination_gcs import LogsArchiveDestinationGCS
        from datadog_api_client.v2.model.logs_archive_destination_s3 import LogsArchiveDestinationS3

        return {
            "oneOf": [
                LogsArchiveDestinationAzure,
                LogsArchiveDestinationGCS,
                LogsArchiveDestinationS3,
            ],
        }



"""
List tags by metric name returns "Success" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.metrics_api import MetricsApi

# there is a valid "metric_tag_configuration" in the system
METRIC_TAG_CONFIGURATION_DATA_ID = environ["METRIC_TAG_CONFIGURATION_DATA_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.list_tags_by_metric_name(
        metric_name=METRIC_TAG_CONFIGURATION_DATA_ID,
    )

    print(response)



"""
Get details of an incident team returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.incident_teams_api import IncidentTeamsApi

# there is a valid "team" in the system
TEAM_DATA_ID = environ["TEAM_DATA_ID"]

configuration = Configuration()
configuration.unstable_operations["get_incident_team"] = True
with ApiClient(configuration) as api_client:
    api_instance = IncidentTeamsApi(api_client)
    response = api_instance.get_incident_team(
        team_id=TEAM_DATA_ID,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_color_preference import WidgetColorPreference
    from datadog_api_client.v1.model.widget_monitor_summary_display_format import WidgetMonitorSummaryDisplayFormat
    from datadog_api_client.v1.model.widget_monitor_summary_sort import WidgetMonitorSummarySort
    from datadog_api_client.v1.model.widget_summary_type import WidgetSummaryType
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.monitor_summary_widget_definition_type import MonitorSummaryWidgetDefinitionType


class MonitorSummaryWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_color_preference import WidgetColorPreference
        from datadog_api_client.v1.model.widget_monitor_summary_display_format import WidgetMonitorSummaryDisplayFormat
        from datadog_api_client.v1.model.widget_monitor_summary_sort import WidgetMonitorSummarySort
        from datadog_api_client.v1.model.widget_summary_type import WidgetSummaryType
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.monitor_summary_widget_definition_type import (
            MonitorSummaryWidgetDefinitionType,
        )

        return {
            "color_preference": (WidgetColorPreference,),
            "count": (int,),
            "display_format": (WidgetMonitorSummaryDisplayFormat,),
            "hide_zero_counts": (bool,),
            "query": (str,),
            "show_last_triggered": (bool,),
            "show_priority": (bool,),
            "sort": (WidgetMonitorSummarySort,),
            "start": (int,),
            "summary_type": (WidgetSummaryType,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (MonitorSummaryWidgetDefinitionType,),
        }

    attribute_map = {
        "color_preference": "color_preference",
        "count": "count",
        "display_format": "display_format",
        "hide_zero_counts": "hide_zero_counts",
        "query": "query",
        "show_last_triggered": "show_last_triggered",
        "show_priority": "show_priority",
        "sort": "sort",
        "start": "start",
        "summary_type": "summary_type",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
    }

    def __init__(
        self_,
        query: str,
        type: MonitorSummaryWidgetDefinitionType,
        color_preference: Union[WidgetColorPreference, UnsetType] = unset,
        count: Union[int, UnsetType] = unset,
        display_format: Union[WidgetMonitorSummaryDisplayFormat, UnsetType] = unset,
        hide_zero_counts: Union[bool, UnsetType] = unset,
        show_last_triggered: Union[bool, UnsetType] = unset,
        show_priority: Union[bool, UnsetType] = unset,
        sort: Union[WidgetMonitorSummarySort, UnsetType] = unset,
        start: Union[int, UnsetType] = unset,
        summary_type: Union[WidgetSummaryType, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The monitor summary widget displays a summary view of all your Datadog monitors, or a subset based on a query. Only available on FREE layout dashboards.

        :param color_preference: Which color to use on the widget.
        :type color_preference: WidgetColorPreference, optional

        :param count: The number of monitors to display. **Deprecated**.
        :type count: int, optional

        :param display_format: What to display on the widget.
        :type display_format: WidgetMonitorSummaryDisplayFormat, optional

        :param hide_zero_counts: Whether to show counts of 0 or not.
        :type hide_zero_counts: bool, optional

        :param query: Query to filter the monitors with.
        :type query: str

        :param show_last_triggered: Whether to show the time that has elapsed since the monitor/group triggered.
        :type show_last_triggered: bool, optional

        :param show_priority: Whether to show the priorities column.
        :type show_priority: bool, optional

        :param sort: Widget sorting methods.
        :type sort: WidgetMonitorSummarySort, optional

        :param start: The start of the list. Typically 0. **Deprecated**.
        :type start: int, optional

        :param summary_type: Which summary type should be used.
        :type summary_type: WidgetSummaryType, optional

        :param title: Title of the widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the monitor summary widget.
        :type type: MonitorSummaryWidgetDefinitionType
        """
        if color_preference is not unset:
            kwargs["color_preference"] = color_preference
        if count is not unset:
            kwargs["count"] = count
        if display_format is not unset:
            kwargs["display_format"] = display_format
        if hide_zero_counts is not unset:
            kwargs["hide_zero_counts"] = hide_zero_counts
        if show_last_triggered is not unset:
            kwargs["show_last_triggered"] = show_last_triggered
        if show_priority is not unset:
            kwargs["show_priority"] = show_priority
        if sort is not unset:
            kwargs["sort"] = sort
        if start is not unset:
            kwargs["start"] = start
        if summary_type is not unset:
            kwargs["summary_type"] = summary_type
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        super().__init__(kwargs)

        self_.query = query
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class AuthNMappingsSort(ModelSimple):
    """
    Sorting options for AuthN Mappings.

    :param value: Must be one of ["created_at", "-created_at", "role_id", "-role_id", "saml_assertion_attribute_id", "-saml_assertion_attribute_id", "role.name", "-role.name", "saml_assertion_attribute.attribute_key", "-saml_assertion_attribute.attribute_key", "saml_assertion_attribute.attribute_value", "-saml_assertion_attribute.attribute_value"].
    :type value: str
    """

    allowed_values = {
        "created_at",
        "-created_at",
        "role_id",
        "-role_id",
        "saml_assertion_attribute_id",
        "-saml_assertion_attribute_id",
        "role.name",
        "-role.name",
        "saml_assertion_attribute.attribute_key",
        "-saml_assertion_attribute.attribute_key",
        "saml_assertion_attribute.attribute_value",
        "-saml_assertion_attribute.attribute_value",
    }
    CREATED_AT_ASCENDING: ClassVar["AuthNMappingsSort"]
    CREATED_AT_DESCENDING: ClassVar["AuthNMappingsSort"]
    ROLE_ID_ASCENDING: ClassVar["AuthNMappingsSort"]
    ROLE_ID_DESCENDING: ClassVar["AuthNMappingsSort"]
    SAML_ASSERTION_ATTRIBUTE_ID_ASCENDING: ClassVar["AuthNMappingsSort"]
    SAML_ASSERTION_ATTRIBUTE_ID_DESCENDING: ClassVar["AuthNMappingsSort"]
    ROLE_NAME_ASCENDING: ClassVar["AuthNMappingsSort"]
    ROLE_NAME_DESCENDING: ClassVar["AuthNMappingsSort"]
    SAML_ASSERTION_ATTRIBUTE_KEY_ASCENDING: ClassVar["AuthNMappingsSort"]
    SAML_ASSERTION_ATTRIBUTE_KEY_DESCENDING: ClassVar["AuthNMappingsSort"]
    SAML_ASSERTION_ATTRIBUTE_VALUE_ASCENDING: ClassVar["AuthNMappingsSort"]
    SAML_ASSERTION_ATTRIBUTE_VALUE_DESCENDING: ClassVar["AuthNMappingsSort"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


AuthNMappingsSort.CREATED_AT_ASCENDING = AuthNMappingsSort("created_at")
AuthNMappingsSort.CREATED_AT_DESCENDING = AuthNMappingsSort("-created_at")
AuthNMappingsSort.ROLE_ID_ASCENDING = AuthNMappingsSort("role_id")
AuthNMappingsSort.ROLE_ID_DESCENDING = AuthNMappingsSort("-role_id")
AuthNMappingsSort.SAML_ASSERTION_ATTRIBUTE_ID_ASCENDING = AuthNMappingsSort("saml_assertion_attribute_id")
AuthNMappingsSort.SAML_ASSERTION_ATTRIBUTE_ID_DESCENDING = AuthNMappingsSort("-saml_assertion_attribute_id")
AuthNMappingsSort.ROLE_NAME_ASCENDING = AuthNMappingsSort("role.name")
AuthNMappingsSort.ROLE_NAME_DESCENDING = AuthNMappingsSort("-role.name")
AuthNMappingsSort.SAML_ASSERTION_ATTRIBUTE_KEY_ASCENDING = AuthNMappingsSort("saml_assertion_attribute.attribute_key")
AuthNMappingsSort.SAML_ASSERTION_ATTRIBUTE_KEY_DESCENDING = AuthNMappingsSort("-saml_assertion_attribute.attribute_key")
AuthNMappingsSort.SAML_ASSERTION_ATTRIBUTE_VALUE_ASCENDING = AuthNMappingsSort(
    "saml_assertion_attribute.attribute_value"
)
AuthNMappingsSort.SAML_ASSERTION_ATTRIBUTE_VALUE_DESCENDING = AuthNMappingsSort(
    "-saml_assertion_attribute.attribute_value"
)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.incident_timeline_cell_markdown_content_type import (
        IncidentTimelineCellMarkdownContentType,
    )
    from datadog_api_client.v2.model.incident_timeline_cell_markdown_create_attributes_content import (
        IncidentTimelineCellMarkdownCreateAttributesContent,
    )


class IncidentTimelineCellMarkdownCreateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.incident_timeline_cell_markdown_content_type import (
            IncidentTimelineCellMarkdownContentType,
        )
        from datadog_api_client.v2.model.incident_timeline_cell_markdown_create_attributes_content import (
            IncidentTimelineCellMarkdownCreateAttributesContent,
        )

        return {
            "cell_type": (IncidentTimelineCellMarkdownContentType,),
            "content": (IncidentTimelineCellMarkdownCreateAttributesContent,),
            "important": (bool,),
        }

    attribute_map = {
        "cell_type": "cell_type",
        "content": "content",
        "important": "important",
    }

    def __init__(
        self_,
        cell_type: IncidentTimelineCellMarkdownContentType,
        content: IncidentTimelineCellMarkdownCreateAttributesContent,
        important: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Timeline cell data for Markdown timeline cells for a create request.

        :param cell_type: Type of the Markdown timeline cell.
        :type cell_type: IncidentTimelineCellMarkdownContentType

        :param content: The Markdown timeline cell contents.
        :type content: IncidentTimelineCellMarkdownCreateAttributesContent

        :param important: A flag indicating whether the timeline cell is important and should be highlighted.
        :type important: bool, optional
        """
        if important is not unset:
            kwargs["important"] = important
        super().__init__(kwargs)

        self_.cell_type = cell_type
        self_.content = content



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.cloud_configuration_rule_case_create import CloudConfigurationRuleCaseCreate
    from datadog_api_client.v2.model.cloud_configuration_rule_compliance_signal_options import (
        CloudConfigurationRuleComplianceSignalOptions,
    )
    from datadog_api_client.v2.model.cloud_configuration_rule_options import CloudConfigurationRuleOptions
    from datadog_api_client.v2.model.cloud_configuration_rule_type import CloudConfigurationRuleType


class CloudConfigurationRuleCreatePayload(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.cloud_configuration_rule_case_create import CloudConfigurationRuleCaseCreate
        from datadog_api_client.v2.model.cloud_configuration_rule_compliance_signal_options import (
            CloudConfigurationRuleComplianceSignalOptions,
        )
        from datadog_api_client.v2.model.cloud_configuration_rule_options import CloudConfigurationRuleOptions
        from datadog_api_client.v2.model.cloud_configuration_rule_type import CloudConfigurationRuleType

        return {
            "cases": ([CloudConfigurationRuleCaseCreate],),
            "compliance_signal_options": (CloudConfigurationRuleComplianceSignalOptions,),
            "is_enabled": (bool,),
            "message": (str,),
            "name": (str,),
            "options": (CloudConfigurationRuleOptions,),
            "tags": ([str],),
            "type": (CloudConfigurationRuleType,),
        }

    attribute_map = {
        "cases": "cases",
        "compliance_signal_options": "complianceSignalOptions",
        "is_enabled": "isEnabled",
        "message": "message",
        "name": "name",
        "options": "options",
        "tags": "tags",
        "type": "type",
    }

    def __init__(
        self_,
        cases: List[CloudConfigurationRuleCaseCreate],
        compliance_signal_options: CloudConfigurationRuleComplianceSignalOptions,
        is_enabled: bool,
        message: str,
        name: str,
        options: CloudConfigurationRuleOptions,
        tags: Union[List[str], UnsetType] = unset,
        type: Union[CloudConfigurationRuleType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Create a new cloud configuration rule.

        :param cases: Description of generated findings and signals (severity and channels to be notified in case of a signal). Must contain exactly one item.
        :type cases: [CloudConfigurationRuleCaseCreate]

        :param compliance_signal_options: How to generate compliance signals. Useful for cloud_configuration rules only.
        :type compliance_signal_options: CloudConfigurationRuleComplianceSignalOptions

        :param is_enabled: Whether the rule is enabled.
        :type is_enabled: bool

        :param message: Message in markdown format for generated findings and signals.
        :type message: str

        :param name: The name of the rule.
        :type name: str

        :param options: Options on cloud configuration rules.
        :type options: CloudConfigurationRuleOptions

        :param tags: Tags for generated findings and signals.
        :type tags: [str], optional

        :param type: The rule type.
        :type type: CloudConfigurationRuleType, optional
        """
        if tags is not unset:
            kwargs["tags"] = tags
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)

        self_.cases = cases
        self_.compliance_signal_options = compliance_signal_options
        self_.is_enabled = is_enabled
        self_.message = message
        self_.name = name
        self_.options = options



"""
Get items of a Dashboard List returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.dashboard_lists_api import DashboardListsApi

# there is a valid "dashboard_list" in the system
DASHBOARD_LIST_ID = environ["DASHBOARD_LIST_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardListsApi(api_client)
    response = api_instance.get_dashboard_list_items(
        dashboard_list_id=int(DASHBOARD_LIST_ID),
    )

    print(response)



"""
Create a log-based metric returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.logs_metrics_api import LogsMetricsApi
from datadog_api_client.v2.model.logs_metric_compute import LogsMetricCompute
from datadog_api_client.v2.model.logs_metric_compute_aggregation_type import LogsMetricComputeAggregationType
from datadog_api_client.v2.model.logs_metric_create_attributes import LogsMetricCreateAttributes
from datadog_api_client.v2.model.logs_metric_create_data import LogsMetricCreateData
from datadog_api_client.v2.model.logs_metric_create_request import LogsMetricCreateRequest
from datadog_api_client.v2.model.logs_metric_type import LogsMetricType

body = LogsMetricCreateRequest(
    data=LogsMetricCreateData(
        id="Example-Create_a_log_based_metric_returns_OK_response",
        type=LogsMetricType.LOGS_METRICS,
        attributes=LogsMetricCreateAttributes(
            compute=LogsMetricCompute(
                aggregation_type=LogsMetricComputeAggregationType.DISTRIBUTION,
                include_percentiles=True,
                path="@duration",
            ),
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsMetricsApi(api_client)
    response = api_instance.create_logs_metric(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class LogsIndexesOrder(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "index_names": ([str],),
        }

    attribute_map = {
        "index_names": "index_names",
    }

    def __init__(self_, index_names: List[str], **kwargs):
        """
        Object containing the ordered list of log index names.

        :param index_names: Array of strings identifying by their name(s) the index(es) of your organization.
            Logs are tested against the query filter of each index one by one, following the order of the array.
            Logs are eventually stored in the first matching index.
        :type index_names: [str]
        """
        super().__init__(kwargs)

        self_.index_names = index_names



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.logs_storage_tier import LogsStorageTier


class LogsQueryFilter(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.logs_storage_tier import LogsStorageTier

        return {
            "_from": (str,),
            "indexes": ([str],),
            "query": (str,),
            "storage_tier": (LogsStorageTier,),
            "to": (str,),
        }

    attribute_map = {
        "_from": "from",
        "indexes": "indexes",
        "query": "query",
        "storage_tier": "storage_tier",
        "to": "to",
    }

    def __init__(
        self_,
        _from: Union[str, UnsetType] = unset,
        indexes: Union[List[str], UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        storage_tier: Union[LogsStorageTier, UnsetType] = unset,
        to: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The search and filter query settings

        :param _from: The minimum time for the requested logs, supports date math and regular timestamps (milliseconds).
        :type _from: str, optional

        :param indexes: For customers with multiple indexes, the indexes to search. Defaults to ['*'] which means all indexes.
        :type indexes: [str], optional

        :param query: The search query - following the log search syntax.
        :type query: str, optional

        :param storage_tier: Specifies storage type as indexes or online-archives
        :type storage_tier: LogsStorageTier, optional

        :param to: The maximum time for the requested logs, supports date math and regular timestamps (milliseconds).
        :type to: str, optional
        """
        if _from is not unset:
            kwargs["_from"] = _from
        if indexes is not unset:
            kwargs["indexes"] = indexes
        if query is not unset:
            kwargs["query"] = query
        if storage_tier is not unset:
            kwargs["storage_tier"] = storage_tier
        if to is not unset:
            kwargs["to"] = to
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MonitorDeviceID(ModelSimple):
    """
    ID of the device the Synthetics monitor is running on. Same as `SyntheticsDeviceID`.

    :param value: Must be one of ["laptop_large", "tablet", "mobile_small", "chrome.laptop_large", "chrome.tablet", "chrome.mobile_small", "firefox.laptop_large", "firefox.tablet", "firefox.mobile_small"].
    :type value: str
    """

    allowed_values = {
        "laptop_large",
        "tablet",
        "mobile_small",
        "chrome.laptop_large",
        "chrome.tablet",
        "chrome.mobile_small",
        "firefox.laptop_large",
        "firefox.tablet",
        "firefox.mobile_small",
    }
    LAPTOP_LARGE: ClassVar["MonitorDeviceID"]
    TABLET: ClassVar["MonitorDeviceID"]
    MOBILE_SMALL: ClassVar["MonitorDeviceID"]
    CHROME_LAPTOP_LARGE: ClassVar["MonitorDeviceID"]
    CHROME_TABLET: ClassVar["MonitorDeviceID"]
    CHROME_MOBILE_SMALL: ClassVar["MonitorDeviceID"]
    FIREFOX_LAPTOP_LARGE: ClassVar["MonitorDeviceID"]
    FIREFOX_TABLET: ClassVar["MonitorDeviceID"]
    FIREFOX_MOBILE_SMALL: ClassVar["MonitorDeviceID"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


MonitorDeviceID.LAPTOP_LARGE = MonitorDeviceID("laptop_large")
MonitorDeviceID.TABLET = MonitorDeviceID("tablet")
MonitorDeviceID.MOBILE_SMALL = MonitorDeviceID("mobile_small")
MonitorDeviceID.CHROME_LAPTOP_LARGE = MonitorDeviceID("chrome.laptop_large")
MonitorDeviceID.CHROME_TABLET = MonitorDeviceID("chrome.tablet")
MonitorDeviceID.CHROME_MOBILE_SMALL = MonitorDeviceID("chrome.mobile_small")
MonitorDeviceID.FIREFOX_LAPTOP_LARGE = MonitorDeviceID("firefox.laptop_large")
MonitorDeviceID.FIREFOX_TABLET = MonitorDeviceID("firefox.tablet")
MonitorDeviceID.FIREFOX_MOBILE_SMALL = MonitorDeviceID("firefox.mobile_small")



"""
Get an SLO correction for an SLO returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.service_level_objective_corrections_api import ServiceLevelObjectiveCorrectionsApi

# there is a valid "correction" for "slo"
CORRECTION_DATA_ID = environ["CORRECTION_DATA_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceLevelObjectiveCorrectionsApi(api_client)
    response = api_instance.get_slo_correction(
        slo_correction_id=CORRECTION_DATA_ID,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class APIKeysSort(ModelSimple):
    """
    Sorting options

    :param value: If omitted defaults to "name". Must be one of ["created_at", "-created_at", "last4", "-last4", "modified_at", "-modified_at", "name", "-name"].
    :type value: str
    """

    allowed_values = {
        "created_at",
        "-created_at",
        "last4",
        "-last4",
        "modified_at",
        "-modified_at",
        "name",
        "-name",
    }
    CREATED_AT_ASCENDING: ClassVar["APIKeysSort"]
    CREATED_AT_DESCENDING: ClassVar["APIKeysSort"]
    LAST4_ASCENDING: ClassVar["APIKeysSort"]
    LAST4_DESCENDING: ClassVar["APIKeysSort"]
    MODIFIED_AT_ASCENDING: ClassVar["APIKeysSort"]
    MODIFIED_AT_DESCENDING: ClassVar["APIKeysSort"]
    NAME_ASCENDING: ClassVar["APIKeysSort"]
    NAME_DESCENDING: ClassVar["APIKeysSort"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


APIKeysSort.CREATED_AT_ASCENDING = APIKeysSort("created_at")
APIKeysSort.CREATED_AT_DESCENDING = APIKeysSort("-created_at")
APIKeysSort.LAST4_ASCENDING = APIKeysSort("last4")
APIKeysSort.LAST4_DESCENDING = APIKeysSort("-last4")
APIKeysSort.MODIFIED_AT_ASCENDING = APIKeysSort("modified_at")
APIKeysSort.MODIFIED_AT_DESCENDING = APIKeysSort("-modified_at")
APIKeysSort.NAME_ASCENDING = APIKeysSort("name")
APIKeysSort.NAME_DESCENDING = APIKeysSort("-name")



"""
Timeseries cross product query returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.metrics_api import MetricsApi
from datadog_api_client.v2.model.formula_limit import FormulaLimit
from datadog_api_client.v2.model.metrics_data_source import MetricsDataSource
from datadog_api_client.v2.model.metrics_timeseries_query import MetricsTimeseriesQuery
from datadog_api_client.v2.model.query_formula import QueryFormula
from datadog_api_client.v2.model.query_sort_order import QuerySortOrder
from datadog_api_client.v2.model.timeseries_formula_query_request import TimeseriesFormulaQueryRequest
from datadog_api_client.v2.model.timeseries_formula_request import TimeseriesFormulaRequest
from datadog_api_client.v2.model.timeseries_formula_request_attributes import TimeseriesFormulaRequestAttributes
from datadog_api_client.v2.model.timeseries_formula_request_queries import TimeseriesFormulaRequestQueries
from datadog_api_client.v2.model.timeseries_formula_request_type import TimeseriesFormulaRequestType

body = TimeseriesFormulaQueryRequest(
    data=TimeseriesFormulaRequest(
        attributes=TimeseriesFormulaRequestAttributes(
            formulas=[
                QueryFormula(
                    formula="a",
                    limit=FormulaLimit(
                        count=10,
                        order=QuerySortOrder.DESC,
                    ),
                ),
            ],
            _from=1671612804000,
            interval=5000,
            queries=TimeseriesFormulaRequestQueries(
                [
                    MetricsTimeseriesQuery(
                        data_source=MetricsDataSource.METRICS,
                        query="avg:system.cpu.user{*}",
                        name="a",
                    ),
                ]
            ),
            to=1671620004000,
        ),
        type=TimeseriesFormulaRequestType.TIMESERIES_REQUEST,
    ),
)

configuration = Configuration()
configuration.unstable_operations["query_timeseries_data"] = True
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.query_timeseries_data(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class WebhooksIntegrationCustomVariableUpdateRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "is_secret": (bool,),
            "name": (str,),
            "value": (str,),
        }

    attribute_map = {
        "is_secret": "is_secret",
        "name": "name",
        "value": "value",
    }

    def __init__(
        self_,
        is_secret: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        value: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Update request of a custom variable object.

        *All properties are optional.*

        :param is_secret: Make custom variable is secret or not.
            If the custom variable is secret, the value is not returned in the response payload.
        :type is_secret: bool, optional

        :param name: The name of the variable. It corresponds with ``<CUSTOM_VARIABLE_NAME>``. It must only contains upper-case characters, integers or underscores.
        :type name: str, optional

        :param value: Value of the custom variable.
        :type value: str, optional
        """
        if is_secret is not unset:
            kwargs["is_secret"] = is_secret
        if name is not unset:
            kwargs["name"] = name
        if value is not unset:
            kwargs["value"] = value
        super().__init__(kwargs)



"""
Update a downtime returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.downtimes_api import DowntimesApi
from datadog_api_client.v1.model.downtime import Downtime

# there is a valid "downtime" in the system
DOWNTIME_ID = environ["DOWNTIME_ID"]

body = Downtime(
    message="Example-Update_a_downtime_returns_OK_response-updated",
    mute_first_recovery_notification=True,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DowntimesApi(api_client)
    response = api_instance.update_downtime(downtime_id=int(DOWNTIME_ID), body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class HostMuteResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "action": (str,),
            "end": (int,),
            "hostname": (str,),
            "message": (str,),
        }

    attribute_map = {
        "action": "action",
        "end": "end",
        "hostname": "hostname",
        "message": "message",
    }

    def __init__(
        self_,
        action: Union[str, UnsetType] = unset,
        end: Union[int, UnsetType] = unset,
        hostname: Union[str, UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response with the list of muted host for your organization.

        :param action: Action applied to the hosts.
        :type action: str, optional

        :param end: POSIX timestamp in seconds when the host is unmuted.
        :type end: int, optional

        :param hostname: The host name.
        :type hostname: str, optional

        :param message: Message associated with the mute.
        :type message: str, optional
        """
        if action is not unset:
            kwargs["action"] = action
        if end is not unset:
            kwargs["end"] = end
        if hostname is not unset:
            kwargs["hostname"] = hostname
        if message is not unset:
            kwargs["message"] = message
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.opsgenie_service_region_type import OpsgenieServiceRegionType


class OpsgenieServiceUpdateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.opsgenie_service_region_type import OpsgenieServiceRegionType

        return {
            "custom_url": (str, none_type),
            "name": (str,),
            "opsgenie_api_key": (str,),
            "region": (OpsgenieServiceRegionType,),
        }

    attribute_map = {
        "custom_url": "custom_url",
        "name": "name",
        "opsgenie_api_key": "opsgenie_api_key",
        "region": "region",
    }

    def __init__(
        self_,
        custom_url: Union[str, none_type, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        opsgenie_api_key: Union[str, UnsetType] = unset,
        region: Union[OpsgenieServiceRegionType, UnsetType] = unset,
        **kwargs,
    ):
        """
        The Opsgenie service attributes for an update request.

        :param custom_url: The custom URL for a custom region.
        :type custom_url: str, none_type, optional

        :param name: The name for the Opsgenie service.
        :type name: str, optional

        :param opsgenie_api_key: The Opsgenie API key for your Opsgenie service.
        :type opsgenie_api_key: str, optional

        :param region: The region for the Opsgenie service.
        :type region: OpsgenieServiceRegionType, optional
        """
        if custom_url is not unset:
            kwargs["custom_url"] = custom_url
        if name is not unset:
            kwargs["name"] = name
        if opsgenie_api_key is not unset:
            kwargs["opsgenie_api_key"] = opsgenie_api_key
        if region is not unset:
            kwargs["region"] = region
        super().__init__(kwargs)



"""
Create an API GRPC test returns "OK - Returns the created test details." response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
from datadog_api_client.v1.model.synthetics_api_test_config import SyntheticsAPITestConfig
from datadog_api_client.v1.model.synthetics_api_test_type import SyntheticsAPITestType
from datadog_api_client.v1.model.synthetics_assertion_operator import SyntheticsAssertionOperator
from datadog_api_client.v1.model.synthetics_assertion_target import SyntheticsAssertionTarget
from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType
from datadog_api_client.v1.model.synthetics_test_details_sub_type import SyntheticsTestDetailsSubType
from datadog_api_client.v1.model.synthetics_test_metadata import SyntheticsTestMetadata
from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
from datadog_api_client.v1.model.synthetics_test_options_monitor_options import SyntheticsTestOptionsMonitorOptions
from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest

body = SyntheticsAPITest(
    config=SyntheticsAPITestConfig(
        assertions=[
            SyntheticsAssertionTarget(
                operator=SyntheticsAssertionOperator.IS,
                target=1,
                type=SyntheticsAssertionType.GRPC_HEALTHCHECK_STATUS,
            ),
        ],
        request=SyntheticsTestRequest(
            host="localhost",
            port=50051,
            service="Hello",
            method="GET",
            message="",
            metadata=SyntheticsTestMetadata(),
        ),
    ),
    locations=[
        "aws:us-east-2",
    ],
    message="BDD test payload: synthetics_api_grpc_test_payload.json",
    name="Example-Create_an_API_GRPC_test_returns_OK_Returns_the_created_test_details_response",
    options=SyntheticsTestOptions(
        min_failure_duration=0,
        min_location_failed=1,
        monitor_options=SyntheticsTestOptionsMonitorOptions(
            renotify_interval=0,
        ),
        monitor_name="Example-Create_an_API_GRPC_test_returns_OK_Returns_the_created_test_details_response",
        tick_every=60,
    ),
    subtype=SyntheticsTestDetailsSubType.GRPC,
    tags=[
        "testing:api",
    ],
    type=SyntheticsAPITestType.API,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.create_synthetics_api_test(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    file_type,
    unset,
    UnsetType,
)


class IdPMetadataFormData(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "idp_file": (file_type,),
        }

    attribute_map = {
        "idp_file": "idp_file",
    }

    def __init__(self_, idp_file: Union[file_type, UnsetType] = unset, **kwargs):
        """
        The form data submitted to upload IdP metadata

        :param idp_file: The IdP metadata XML file
        :type idp_file: file_type, optional
        """
        if idp_file is not unset:
            kwargs["idp_file"] = idp_file
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SyntheticsSSLCertificateIssuer(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "c": (str,),
            "cn": (str,),
            "l": (str,),
            "o": (str,),
            "ou": (str,),
            "st": (str,),
        }

    attribute_map = {
        "c": "C",
        "cn": "CN",
        "l": "L",
        "o": "O",
        "ou": "OU",
        "st": "ST",
    }

    def __init__(
        self_,
        c: Union[str, UnsetType] = unset,
        cn: Union[str, UnsetType] = unset,
        l: Union[str, UnsetType] = unset,
        o: Union[str, UnsetType] = unset,
        ou: Union[str, UnsetType] = unset,
        st: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object describing the issuer of a SSL certificate.

        :param c: Country Name that issued the certificate.
        :type c: str, optional

        :param cn: Common Name that issued certificate.
        :type cn: str, optional

        :param l: Locality that issued the certificate.
        :type l: str, optional

        :param o: Organization that issued the certificate.
        :type o: str, optional

        :param ou: Organizational Unit that issued the certificate.
        :type ou: str, optional

        :param st: State Or Province Name that issued the certificate.
        :type st: str, optional
        """
        if c is not unset:
            kwargs["c"] = c
        if cn is not unset:
            kwargs["cn"] = cn
        if l is not unset:
            kwargs["l"] = l
        if o is not unset:
            kwargs["o"] = o
        if ou is not unset:
            kwargs["ou"] = ou
        if st is not unset:
            kwargs["st"] = st
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class TagToHosts(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "tags": ({str: ([str],)},),
        }

    attribute_map = {
        "tags": "tags",
    }

    def __init__(self_, tags: Union[Dict[str, List[str]], UnsetType] = unset, **kwargs):
        """
        In this object, the key is the tag, the value is a list of host names that are reporting that tag.

        :param tags: A list of tags to apply to the host.
        :type tags: {str: ([str],)}, optional
        """
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class ChargebackBreakdown(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "charge_type": (str,),
            "cost": (float,),
            "product_name": (str,),
        }

    attribute_map = {
        "charge_type": "charge_type",
        "cost": "cost",
        "product_name": "product_name",
    }

    def __init__(
        self_,
        charge_type: Union[str, UnsetType] = unset,
        cost: Union[float, UnsetType] = unset,
        product_name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Charges breakdown.

        :param charge_type: The type of charge for a particular product.
        :type charge_type: str, optional

        :param cost: The cost for a particular product and charge type during a given month.
        :type cost: float, optional

        :param product_name: The product for which cost is being reported.
        :type product_name: str, optional
        """
        if charge_type is not unset:
            kwargs["charge_type"] = charge_type
        if cost is not unset:
            kwargs["cost"] = cost
        if product_name is not unset:
            kwargs["product_name"] = product_name
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class WidgetFormulaStyle(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "palette": (str,),
            "palette_index": (int,),
        }

    attribute_map = {
        "palette": "palette",
        "palette_index": "palette_index",
    }

    def __init__(self_, palette: Union[str, UnsetType] = unset, palette_index: Union[int, UnsetType] = unset, **kwargs):
        """
        Styling options for widget formulas.

        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors
        :type palette: str, optional

        :param palette_index: Index specifying which color to use within the palette.
        :type palette_index: int, optional
        """
        if palette is not unset:
            kwargs["palette"] = palette
        if palette_index is not unset:
            kwargs["palette_index"] = palette_index
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.metric_estimate_type import MetricEstimateType


class MetricEstimateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.metric_estimate_type import MetricEstimateType

        return {
            "estimate_type": (MetricEstimateType,),
            "estimated_at": (datetime,),
            "estimated_output_series": (int,),
        }

    attribute_map = {
        "estimate_type": "estimate_type",
        "estimated_at": "estimated_at",
        "estimated_output_series": "estimated_output_series",
    }

    def __init__(
        self_,
        estimate_type: Union[MetricEstimateType, UnsetType] = unset,
        estimated_at: Union[datetime, UnsetType] = unset,
        estimated_output_series: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object containing the definition of a metric estimate attribute.

        :param estimate_type: Estimate type based on the queried configuration. By default, ``count_or_gauge`` is returned. ``distribution`` is returned for distribution metrics without percentiles enabled. Lastly, ``percentile`` is returned if ``filter[pct]=true`` is queried with a distribution metric.
        :type estimate_type: MetricEstimateType, optional

        :param estimated_at: Timestamp when the cardinality estimate was requested.
        :type estimated_at: datetime, optional

        :param estimated_output_series: Estimated cardinality of the metric based on the queried configuration.
        :type estimated_output_series: int, optional
        """
        if estimate_type is not unset:
            kwargs["estimate_type"] = estimate_type
        if estimated_at is not unset:
            kwargs["estimated_at"] = estimated_at
        if estimated_output_series is not unset:
            kwargs["estimated_output_series"] = estimated_output_series
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class ServiceDefinitionV2LinkType(ModelSimple):
    """
    Link type.

    :param value: Must be one of ["doc", "wiki", "runbook", "url", "repo", "dashboard", "oncall", "code", "link"].
    :type value: str
    """

    allowed_values = {
        "doc",
        "wiki",
        "runbook",
        "url",
        "repo",
        "dashboard",
        "oncall",
        "code",
        "link",
    }
    DOC: ClassVar["ServiceDefinitionV2LinkType"]
    WIKI: ClassVar["ServiceDefinitionV2LinkType"]
    RUNBOOK: ClassVar["ServiceDefinitionV2LinkType"]
    URL: ClassVar["ServiceDefinitionV2LinkType"]
    REPO: ClassVar["ServiceDefinitionV2LinkType"]
    DASHBOARD: ClassVar["ServiceDefinitionV2LinkType"]
    ONCALL: ClassVar["ServiceDefinitionV2LinkType"]
    CODE: ClassVar["ServiceDefinitionV2LinkType"]
    LINK: ClassVar["ServiceDefinitionV2LinkType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


ServiceDefinitionV2LinkType.DOC = ServiceDefinitionV2LinkType("doc")
ServiceDefinitionV2LinkType.WIKI = ServiceDefinitionV2LinkType("wiki")
ServiceDefinitionV2LinkType.RUNBOOK = ServiceDefinitionV2LinkType("runbook")
ServiceDefinitionV2LinkType.URL = ServiceDefinitionV2LinkType("url")
ServiceDefinitionV2LinkType.REPO = ServiceDefinitionV2LinkType("repo")
ServiceDefinitionV2LinkType.DASHBOARD = ServiceDefinitionV2LinkType("dashboard")
ServiceDefinitionV2LinkType.ONCALL = ServiceDefinitionV2LinkType("oncall")
ServiceDefinitionV2LinkType.CODE = ServiceDefinitionV2LinkType("code")
ServiceDefinitionV2LinkType.LINK = ServiceDefinitionV2LinkType("link")



"""
Mute a host returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.hosts_api import HostsApi
from datadog_api_client.v1.model.host_mute_settings import HostMuteSettings

body = HostMuteSettings(
    end=1579098130,
    message="Muting this host for a test!",
    override=False,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = HostsApi(api_client)
    response = api_instance.mute_host(host_name="host_name", body=body)

    print(response)



"""
Search tests events returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.ci_visibility_tests_api import CIVisibilityTestsApi
from datadog_api_client.v2.model.ci_app_query_options import CIAppQueryOptions
from datadog_api_client.v2.model.ci_app_query_page_options import CIAppQueryPageOptions
from datadog_api_client.v2.model.ci_app_sort import CIAppSort
from datadog_api_client.v2.model.ci_app_test_events_request import CIAppTestEventsRequest
from datadog_api_client.v2.model.ci_app_tests_query_filter import CIAppTestsQueryFilter

body = CIAppTestEventsRequest(
    filter=CIAppTestsQueryFilter(
        _from="now-15m",
        query="@test.service:web-ui-tests AND @test.status:skip",
        to="now",
    ),
    options=CIAppQueryOptions(
        timezone="GMT",
    ),
    page=CIAppQueryPageOptions(
        limit=25,
    ),
    sort=CIAppSort.TIMESTAMP_ASCENDING,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = CIVisibilityTestsApi(api_client)
    response = api_instance.search_ci_app_test_events(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class EventStatusType(ModelSimple):
    """
    If an alert event is enabled, its status is one of the following:
        `failure`, `error`, `warning`, `info`, `success`, `user_update`,
        `recommendation`, or `snapshot`.

    :param value: Must be one of ["failure", "error", "warning", "info", "success", "user_update", "recommendation", "snapshot"].
    :type value: str
    """

    allowed_values = {
        "failure",
        "error",
        "warning",
        "info",
        "success",
        "user_update",
        "recommendation",
        "snapshot",
    }
    FAILURE: ClassVar["EventStatusType"]
    ERROR: ClassVar["EventStatusType"]
    WARNING: ClassVar["EventStatusType"]
    INFO: ClassVar["EventStatusType"]
    SUCCESS: ClassVar["EventStatusType"]
    USER_UPDATE: ClassVar["EventStatusType"]
    RECOMMENDATION: ClassVar["EventStatusType"]
    SNAPSHOT: ClassVar["EventStatusType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


EventStatusType.FAILURE = EventStatusType("failure")
EventStatusType.ERROR = EventStatusType("error")
EventStatusType.WARNING = EventStatusType("warning")
EventStatusType.INFO = EventStatusType("info")
EventStatusType.SUCCESS = EventStatusType("success")
EventStatusType.USER_UPDATE = EventStatusType("user_update")
EventStatusType.RECOMMENDATION = EventStatusType("recommendation")
EventStatusType.SNAPSHOT = EventStatusType("snapshot")



"""
Get a webhook integration returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.webhooks_integration_api import WebhooksIntegrationApi

# there is a valid "webhook" in the system
WEBHOOK_NAME = environ["WEBHOOK_NAME"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = WebhooksIntegrationApi(api_client)
    response = api_instance.get_webhooks_integration(
        webhook_name=WEBHOOK_NAME,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class ServiceDefinitionMeta(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "github_html_url": (str,),
            "ingested_schema_version": (str,),
            "ingestion_source": (str,),
            "last_modified_time": (str,),
        }

    attribute_map = {
        "github_html_url": "github-html-url",
        "ingested_schema_version": "ingested-schema-version",
        "ingestion_source": "ingestion-source",
        "last_modified_time": "last-modified-time",
    }

    def __init__(
        self_,
        github_html_url: Union[str, UnsetType] = unset,
        ingested_schema_version: Union[str, UnsetType] = unset,
        ingestion_source: Union[str, UnsetType] = unset,
        last_modified_time: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Metadata about a service definition.

        :param github_html_url: GitHub HTML URL.
        :type github_html_url: str, optional

        :param ingested_schema_version: Ingestion schema version.
        :type ingested_schema_version: str, optional

        :param ingestion_source: Ingestion source of the service definition.
        :type ingestion_source: str, optional

        :param last_modified_time: Last modified time of the service definition.
        :type last_modified_time: str, optional
        """
        if github_html_url is not unset:
            kwargs["github_html_url"] = github_html_url
        if ingested_schema_version is not unset:
            kwargs["ingested_schema_version"] = ingested_schema_version
        if ingestion_source is not unset:
            kwargs["ingestion_source"] = ingestion_source
        if last_modified_time is not unset:
            kwargs["last_modified_time"] = last_modified_time
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class NotebookMetadataType(ModelSimple):
    """
    Metadata type of the notebook.

    :param value: Must be one of ["postmortem", "runbook", "investigation", "documentation", "report"].
    :type value: str
    """

    allowed_values = {
        "postmortem",
        "runbook",
        "investigation",
        "documentation",
        "report",
    }
    POSTMORTEM: ClassVar["NotebookMetadataType"]
    RUNBOOK: ClassVar["NotebookMetadataType"]
    INVESTIGATION: ClassVar["NotebookMetadataType"]
    DOCUMENTATION: ClassVar["NotebookMetadataType"]
    REPORT: ClassVar["NotebookMetadataType"]

    _nullable = True

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


NotebookMetadataType.POSTMORTEM = NotebookMetadataType("postmortem")
NotebookMetadataType.RUNBOOK = NotebookMetadataType("runbook")
NotebookMetadataType.INVESTIGATION = NotebookMetadataType("investigation")
NotebookMetadataType.DOCUMENTATION = NotebookMetadataType("documentation")
NotebookMetadataType.REPORT = NotebookMetadataType("report")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.service_definition_v2_slack_type import ServiceDefinitionV2SlackType


class ServiceDefinitionV2Slack(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.service_definition_v2_slack_type import ServiceDefinitionV2SlackType

        return {
            "contact": (str,),
            "name": (str,),
            "type": (ServiceDefinitionV2SlackType,),
        }

    attribute_map = {
        "contact": "contact",
        "name": "name",
        "type": "type",
    }

    def __init__(
        self_, contact: str, type: ServiceDefinitionV2SlackType, name: Union[str, UnsetType] = unset, **kwargs
    ):
        """
        Service owner's Slack channel.

        :param contact: Slack Channel.
        :type contact: str

        :param name: Contact Slack.
        :type name: str, optional

        :param type: Contact type.
        :type type: ServiceDefinitionV2SlackType
        """
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)

        self_.contact = contact
        self_.type = type



"""
Delete tests returns "OK." response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_delete_tests_payload import SyntheticsDeleteTestsPayload

# there is a valid "synthetics_api_test" in the system
SYNTHETICS_API_TEST_PUBLIC_ID = environ["SYNTHETICS_API_TEST_PUBLIC_ID"]

body = SyntheticsDeleteTestsPayload(
    public_ids=[
        SYNTHETICS_API_TEST_PUBLIC_ID,
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.delete_tests(body=body)

    print(response)
